@@ -4,7 +4,7 @@
  *               for mp3/ogg splitting without decoding
  *
  * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
- * Copyright (c) 2005-2009 Alexandru Munteanu - io_fx@yahoo.fr
+ * Copyright (c) 2005-2010 Alexandru Munteanu - io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net
  *
@@ -189,6 +189,7 @@ typedef struct {
   char *format_string;
   //when we have @n option on output format
   char output_format_digits;
+  int output_alpha_format_digits;
   //format for the cddb cue output
   char format[SPLT_OUTNUM+1][SPLT_MAXOLEN];
 } splt_oformat;
@@ -244,7 +245,7 @@ typedef struct {
   unsigned char genre;
 
   /*
-   * @brief tags version (for mp3) : 1 or 2
+   * @brief tags version (for mp3): 1 or 2 or 1 & 2
    */
   int tags_version;
 } splt_tags;
@@ -302,7 +303,7 @@ typedef struct splt_progres {
   //the maximum number of splits
   int max_splits;
   //the progress type
-  //can be :
+  //can be:
   //SPLT_PROGRESS_PREPARE
   //SPLT_PROGRESS_CREATE
   //SPLT_PROGRESS_SEARCH_SYNC
@@ -333,6 +334,18 @@ typedef struct {
   char password[256];
 } splt_proxy;
 
+//used with the 'put_message' function
+typedef enum {
+  /**
+   * Info message
+   */
+  SPLT_MESSAGE_INFO,
+  /**
+   * Debug message
+   */
+  SPLT_MESSAGE_DEBUG
+} splt_message_type;
+
 typedef struct {
   //total time of the song
   long total_time;
@@ -340,7 +353,7 @@ typedef struct {
   //1 if the first, 2 if the second
   //the number of splitpoints
   int current_split;
-  //for the user feedback : the current split file number
+  //for the user feedback: the current split file number
   int current_split_file_number;
   //how many splits, this will be modified
   //by check_splitpts_inf_song_length()
@@ -360,14 +373,15 @@ typedef struct {
   //user data set by the client for the 'get_silence_level' function
   void *silence_level_client_data;
   //sends a message to the main program to tell him what
-  //he is doing
-  void (*put_message)(const char *);
+  //he is doing; the second parameter is the type of split
+  void (*put_message)(const char *, splt_message_type );
   //structure in which we have all the splitpoints
   splt_point *points;
   //how many tags we have
   int real_tagsnumber;
   //structure in which we have all the tags
   splt_tags *tags;
+  splt_tags tags_like_x;
 } splt_struct;
 
 /**********************************/
@@ -401,7 +415,12 @@ typedef enum {
    * Will create an indefinite number of smaller files with
    * a fixed time length specified by #SPLT_OPT_SPLIT_TIME
    */
-  SPLT_OPTION_TIME_MODE
+  SPLT_OPTION_TIME_MODE,
+  /**
+   * Split in X pieces of equal time length.
+   * X is defined by the #SPLT_OPT_LENGTH_SPLIT_FILE_NUMBER option
+   */
+  SPLT_OPTION_LENGTH_MODE,
 } splt_split_mode_options;
 
 /**
@@ -462,13 +481,15 @@ typedef enum {
   SPLT_NO_TAGS
 } splt_tags_options;
 
+#define SPLT_ORIGINAL_TAGS_DEFAULT "%[@o,@N=1]"
+
 #define SPLT_DEFAULT_OUTPUT "@f_@mm_@ss_@hh__@Mm_@Ss_@Hh"
 
 /**
  * @brief Default output for the cddb and cue.
  * See #mp3splt_set_oformat
  */
-#define SPLT_DEFAULT_CDDB_CUE_OUTPUT "@a - @n - @t"
+#define SPLT_DEFAULT_CDDB_CUE_OUTPUT "@A - @n - @t"
 /**
  * @brief Default output for the syncerror.
  * See #mp3splt_set_oformat
@@ -482,7 +503,7 @@ typedef enum {
 
 //structure with all the options supplied to split the file
 typedef struct {
-  //this can take the following values :
+  //this can take the following values:
   //SPLT_OPTION_NORMAL_MODE
   //SPLT_OPTION_WRAP_MODE
   //SPLT_OPTION_SILENCE_MODE
@@ -490,7 +511,7 @@ typedef struct {
   //SPLT_OPTION_TIME_MODE
   splt_split_mode_options split_mode;
 
-  //might be :
+  //might be:
   //SPLT_TAGS_ORIGINAL_FILE - write tags from original file
   //SPLT_NO_TAGS - does not write any tags
   //SPLT_CURRENT_TAGS - tags issued from the cddb or cue for example
@@ -502,10 +523,10 @@ typedef struct {
   //defines the output filenames
   splt_output_filenames_options output_filenames;
 
-  //quiet mode : don't perform CRC check or other interaction with the user
+  //quiet mode: don't perform CRC check or other interaction with the user
   short quiet_mode;
 
-  //Pretend to split the file, without real split : this option works in
+  //Pretend to split the file, without real split: this option works in
   //all modes except error mode and dewrap split.
   short pretend_to_split;
 
@@ -531,7 +552,7 @@ typedef struct {
   short create_dirs_from_filenames;
 
   //PARAMETERS---------------------------------------
-  //PARAMETERS for option_auto_adjust and option_silence_mode :
+  //PARAMETERS for option_auto_adjust and option_silence_mode:
   //the sound level to be considered silence
   //(it is a float number between -96 and 0. Default is -48 dB)
   float parameter_threshold;
@@ -541,7 +562,7 @@ typedef struct {
   //end;default is 0.8. 
   float parameter_offset;
 
-  //PARAMETERS for option_silence_mode :
+  //PARAMETERS for option_silence_mode:
   //the desired number of tracks
   //(positive integer number of tracks to be split;by default all
   //tracks are split)
@@ -553,7 +574,7 @@ typedef struct {
   //allows you to remove the silence between split tracks
   short parameter_remove_silence;
 
-  //PARAMETERS for option_auto_adjust :
+  //PARAMETERS for option_auto_adjust:
   //the gap value around splitpoint to search for silence
   //(positive integer for the time to decode before and after
   //splitpoint;default gap is 30 seconds)
@@ -573,12 +594,17 @@ typedef struct {
   int enable_silence_log;
 
   /**
-   * If we force the mp3 tags version to 1 or 2;
+   * If we force the mp3 tags version to 1 or 2 or 1 & 2;
    * Set to 0 if force disable;
    * If disabled, original tags version is set to split files,
    *  or version 1 if compiled without libid3tag support
    */
   int force_tags_version;
+  /**
+   * the number of files to be created when splitting by equal time length
+   */
+  int length_split_file_number;
+  int replace_tags_in_tags;
 } splt_options;
 
 /**********************************/
@@ -613,6 +639,7 @@ typedef struct
   float version;
   char *name;
   char *extension;
+  char *upper_extension;
 } splt_plugin_info;
 
 //contains pointers to the plugin functions
@@ -623,7 +650,7 @@ typedef struct {
   void (*dewrap)(void *state, int listonly, const char *dir, int *error);
   void (*set_total_time)(void *state, int *error);
   int (*simple_split)(void *state, const char *output_fname, off_t begin, off_t end);
-  void (*split)(void *state, const char *final_fname, double begin_point,
+  double (*split)(void *state, const char *final_fname, double begin_point,
       double end_point, int *error, int save_end_point);
   int (*scan_silence)(void *state, int *error);
   void (*set_original_tags)(void *state, int *error);
@@ -717,304 +744,105 @@ typedef struct {
   splt_plugins *plug;
   int current_plugin;
 
-  //filename of the silence log : 'mp3splt.log' in the original mp3splt
+  //filename of the silence log: 'mp3splt.log' in the original mp3splt
   char *silence_log_fname;
 } splt_state;
 
 /*****************************************/
 /* Confirmations, errors and messages    */
 
-//error and confirmation messages :
-//sync
-/**
- * @brief Warning, split : mp3 file might be VBR
- */
-#define SPLT_MIGHT_BE_VBR 301
-/**
- * @brief Confirmation, syncerror : syncerror processed ok
- */
-#define SPLT_SYNC_OK 300
-/**
- * @brief Error, syncerror : error for the syncerror
- */
-#define SPLT_ERR_SYNC -300
-/**
- * @brief Error, syncerror : no sync errors found
- */
-#define SPLT_ERR_NO_SYNC_FOUND -301
-/**
- * @brief Error, syncerror : too many syncerrors found
- */
-#define SPLT_ERR_TOO_MANY_SYNC_ERR -302
+typedef enum {
+  SPLT_OK = 0,
 
-//freedb, cue, cddb
-/**
- * @brief Warning, freedb : maximum number of CD reached
- */
-#define SPLT_FREEDB_MAX_CD_REACHED 104
-/**
- * @brief Confirmation, cue : file processed ok
- */
-#define SPLT_CUE_OK 103
-/**
- * @brief Confirmation, cddb : file processed ok
- */
-#define SPLT_CDDB_OK 102
-/**
- * @brief Confirmation, freedb : file processed ok
- */
-#define SPLT_FREEDB_FILE_OK 101
-/**
- * @brief Confirmation, freedb : search ok
- */
-#define SPLT_FREEDB_OK 100
+  SPLT_OK_SPLIT = 1,
+  SPLT_SPLITPOINT_BIGGER_THAN_LENGTH = 4,
+  SPLT_SILENCE_OK = 5,
+  SPLT_TIME_SPLIT_OK = 6,
+  SPLT_NO_SILENCE_SPLITPOINTS_FOUND = 7,
+  SPLT_OK_SPLIT_EOF = 8,
+  SPLT_LENGTH_SPLIT_OK = 9,
 
-/**
- * @brief Error, freedb : cannot initialise socket
- */
-#define SPLT_FREEDB_ERROR_INITIALISE_SOCKET -101
-/**
- * @brief Error, freedb : cannot get host by name
- */
-#define SPLT_FREEDB_ERROR_CANNOT_GET_HOST -102
-/**
- * @brief Error, freedb : cannot open socket
- */
-#define SPLT_FREEDB_ERROR_CANNOT_OPEN_SOCKET -103
-/**
- * @brief Error, freedb : cannot connect to host
- */
-#define SPLT_FREEDB_ERROR_CANNOT_CONNECT -104
-/**
- * @brief Error, freedb : cannot send message
- */
-#define SPLT_FREEDB_ERROR_CANNOT_SEND_MESSAGE -105
-/**
- * @brief Error, freedb : invalid server answer
- */
-#define SPLT_FREEDB_ERROR_INVALID_SERVER_ANSWER -106
-/**
- * @brief Error, freedb : site returned 201 error
- */
-#define SPLT_FREEDB_ERROR_SITE_201 -107
-/**
- * @brief Error, freedb : site returned 200 error
- */
-#define SPLT_FREEDB_ERROR_SITE_200 -108
-/**
- * @brief Error, freedb : bad communication between server and client
- */
-#define SPLT_FREEDB_ERROR_BAD_COMMUNICATION -109
-/**
- * @brief Error, freedb : error getting server informations
- */
-#define SPLT_FREEDB_ERROR_GETTING_INFOS -110
-/**
- * @brief Error, freedb : no CD found for the search
- */
-#define SPLT_FREEDB_NO_CD_FOUND -111
-/**
- * @brief Error, freedb : cannot receive message from server
- */
-#define SPLT_FREEDB_ERROR_CANNOT_RECV_MESSAGE -112
-/**
- * @brief Error, cue : invalid cue file, the parse failed
- */
-#define SPLT_INVALID_CUE_FILE -115
-/**
- * @brief Error, cddb : invalid cddb file, the parse failed
- */
-#define SPLT_INVALID_CDDB_FILE -116
-/**
- * @brief Error, freedb : No such CD entry in database
- */
-#define SPLT_FREEDB_NO_SUCH_CD_IN_DATABASE -118
-/**
- * @brief Error, freedb : site returned an unknown error
- */
-#define SPLT_FREEDB_ERROR_SITE -119
+  SPLT_FREEDB_OK = 100,
+  SPLT_FREEDB_FILE_OK = 101,
+  SPLT_CDDB_OK = 102,
+  SPLT_CUE_OK = 103,
+  SPLT_FREEDB_MAX_CD_REACHED = 104,
+  SPLT_AUDACITY_OK = 105,
 
-//wrap
-/**
- * @brief Confirmation, dewrap : dewrap processed ok
- */
-#define SPLT_DEWRAP_OK 200
+  SPLT_DEWRAP_OK = 200,
 
-/**
- * @brief Error, dewrap : file length error
- */
-#define SPLT_DEWRAP_ERR_FILE_LENGTH -200
-/**
- * @brief Error, dewrap : wrapped with a too old version of mp3wrap
- */
-#define SPLT_DEWRAP_ERR_VERSION_OLD -201
-/**
- * @brief Error, dewrap : file damaged
- */
-#define SPLT_DEWRAP_ERR_NO_FILE_OR_BAD_INDEX -202
-/**
- * @brief Error, dewrap : file damaged or incomplete
- */
-#define SPLT_DEWRAP_ERR_FILE_DAMAGED_INCOMPLETE -203
-/**
- * @brief Error, dewrap : file not wrapped or damaged
- */
-#define SPLT_DEWRAP_ERR_FILE_NOT_WRAPED_DAMAGED -204
+  SPLT_SYNC_OK = 300,
+  SPLT_MIGHT_BE_VBR = 301,
 
-/**
- * @brief Warning, split : split, end of file
- */
-#define SPLT_OK_SPLIT_EOF 8
-/**
- * @brief Warning, silence detection : no silence splitpoint found
- */
-#define SPLT_NO_SILENCE_SPLITPOINTS_FOUND 7
-/**
- * @brief Confirmation, time split : time split processed ok
- */
-#define SPLT_TIME_SPLIT_OK 6
-/**
- * @brief Confirmation, silence split : silence split processed ok
- */
-#define SPLT_SILENCE_OK 5
-/**
- * @brief Warning, split : splitpoints bigger than file length
- */
-#define SPLT_SPLITPOINT_BIGGER_THAN_LENGTH 4
-/**
- * @brief Confirmation, split : split
- */
-#define SPLT_OK_SPLIT 1
-/**
- * @brief Confirmation : no error
- */
-#define SPLT_OK 0
+  SPLT_ERR_SYNC = -300,
+  SPLT_ERR_NO_SYNC_FOUND = -301,
+  SPLT_ERR_TOO_MANY_SYNC_ERR = -302,
 
-/**
- * @brief Error, split : not enough splitpoints
- */
-#define SPLT_ERROR_SPLITPOINTS -1
-/**
- * @brief Error, split : cannot open file
- */
-#define SPLT_ERROR_CANNOT_OPEN_FILE -2
-/**
- * @brief Error, split : invalid file for plugin
- */
-#define SPLT_ERROR_INVALID -3
-/**
- * @brief Error, split : splitpoints are equal
- */
-#define SPLT_ERROR_EQUAL_SPLITPOINTS -5
-/**
- * @brief Error, split : splitpoints are not in order
- */
-#define SPLT_ERROR_SPLITPOINTS_NOT_IN_ORDER -6
-/**
- * @brief Error, split : negative splitpoint found
- */
-#define SPLT_ERROR_NEGATIVE_SPLITPOINT -7
-/**
- * @brief Error, split : incorrect split path
- */
-#define SPLT_ERROR_INCORRECT_PATH -8
-/**
- * @brief Error, split : incompatible split options
- */
-#define SPLT_ERROR_INCOMPATIBLE_OPTIONS -10
-/**
- * @brief Error, split : input and output are the same file
- */
-#define SPLT_ERROR_INPUT_OUTPUT_SAME_FILE -12
-/**
- * @brief Error : cannot allocate memory
- */
-#define SPLT_ERROR_CANNOT_ALLOCATE_MEMORY -15
-/**
- * @brief Error, split : cannot open destination file
- */
-#define SPLT_ERROR_CANNOT_OPEN_DEST_FILE -16
-/**
- * @brief Error, split : cannot write to destination file
- */
-#define SPLT_ERROR_CANT_WRITE_TO_OUTPUT_FILE -17
-/**
- * @brief Error, split : error while reading file
- */
-#define SPLT_ERROR_WHILE_READING_FILE -18
-/**
- * @brief Error, split : error while seeking file
- */
-#define SPLT_ERROR_SEEKING_FILE -19
-/**
- * @brief Error, split : begin is out of file
- */
-#define SPLT_ERROR_BEGIN_OUT_OF_FILE -20
-/**
- * @brief Error, split : inexistent input file
- */
-#define SPLT_ERROR_INEXISTENT_FILE -21
-/**
- * @brief Error, split : split canceled
- */
-#define SPLT_SPLIT_CANCELLED -22
-/**
- * @brief Error, the library is being used
- */
-#define SPLT_ERROR_LIBRARY_LOCKED -24
-/**
- * @brief Error, the state has not been initialised with #mp3splt_new_state
- */
-#define SPLT_ERROR_STATE_NULL -25
-/**
- * @brief Error, the time split has a negative value
- */
-#define SPLT_ERROR_NEGATIVE_TIME_SPLIT -26
-/**
- * @brief Error, cannot create output directory
- */
-#define SPLT_ERROR_CANNOT_CREATE_DIRECTORY -27
-/**
- * @brief Error, cannot create output directory
- */
-#define SPLT_ERROR_CANNOT_CLOSE_FILE -28
-/**
- * @brief Error, cannot find plugins
- */
-#define SPLT_ERROR_NO_PLUGIN_FOUND -29
-/**
- * @brief Error, cannot init libltdl
- */
-#define SPLT_ERROR_CANNOT_INIT_LIBLTDL -30
-/**
- * @brief Error, cannot init libltdl
- */
-#define SPLT_ERROR_CRC_FAILED -31
-#define SPLT_ERROR_NO_PLUGIN_FOUND_FOR_FILE -32
-#define SPLT_ERROR_PLUGIN_ERROR -33
-#define SPLT_ERROR_TIME_SPLIT_VALUE_INVALID -34
+  SPLT_OUTPUT_FORMAT_OK = 400,
+  SPLT_OUTPUT_FORMAT_AMBIGUOUS = 401,
 
-//output format
-/**
- * @brief Confirmation, output format : the output format is ok
- */
-#define SPLT_OUTPUT_FORMAT_OK 400
-/**
- * @brief Warning, output format : output format ambigous
- */
-#define SPLT_OUTPUT_FORMAT_AMBIGUOUS 401
+  SPLT_ERROR_SPLITPOINTS = -1,
+  SPLT_ERROR_CANNOT_OPEN_FILE = -2,
+  SPLT_ERROR_INVALID = -3,
+  SPLT_ERROR_EQUAL_SPLITPOINTS = -5,
+  SPLT_ERROR_SPLITPOINTS_NOT_IN_ORDER = -6,
+  SPLT_ERROR_NEGATIVE_SPLITPOINT = -7,
+  SPLT_ERROR_INCORRECT_PATH = -8,
+  SPLT_ERROR_INCOMPATIBLE_OPTIONS = -10,
+  SPLT_ERROR_INPUT_OUTPUT_SAME_FILE = -12,
+  SPLT_ERROR_CANNOT_ALLOCATE_MEMORY = -15,
+  SPLT_ERROR_CANNOT_OPEN_DEST_FILE = -16,
+  SPLT_ERROR_CANT_WRITE_TO_OUTPUT_FILE = -17,
+  SPLT_ERROR_WHILE_READING_FILE = -18,
+  SPLT_ERROR_SEEKING_FILE = -19,
+  SPLT_ERROR_BEGIN_OUT_OF_FILE = -20,
+  SPLT_ERROR_INEXISTENT_FILE = -21,
+  SPLT_SPLIT_CANCELLED = -22,
+  SPLT_ERROR_LIBRARY_LOCKED = -24,
+  SPLT_ERROR_STATE_NULL = -25,
+  SPLT_ERROR_NEGATIVE_TIME_SPLIT = -26,
+  SPLT_ERROR_CANNOT_CREATE_DIRECTORY = -27,
+  SPLT_ERROR_CANNOT_CLOSE_FILE = -28,
+  SPLT_ERROR_NO_PLUGIN_FOUND = -29,
+  SPLT_ERROR_CANNOT_INIT_LIBLTDL = -30,
+  SPLT_ERROR_CRC_FAILED = -31,
+  SPLT_ERROR_NO_PLUGIN_FOUND_FOR_FILE = -32,
+  SPLT_ERROR_PLUGIN_ERROR = -33,
+  SPLT_ERROR_TIME_SPLIT_VALUE_INVALID = -34,
+  SPLT_ERROR_LENGTH_SPLIT_VALUE_INVALID = -35,
+  SPLT_ERROR_CANNOT_GET_TOTAL_TIME = -36,
 
-/**
- * @brief Error, output format : error occured while parsing the
- * output format
- */
-#define SPLT_OUTPUT_FORMAT_ERROR -400
+  SPLT_FREEDB_ERROR_INITIALISE_SOCKET = -101,
+  SPLT_FREEDB_ERROR_CANNOT_GET_HOST = -102,
+  SPLT_FREEDB_ERROR_CANNOT_OPEN_SOCKET = -103,
+  SPLT_FREEDB_ERROR_CANNOT_CONNECT = -104,
+  SPLT_FREEDB_ERROR_CANNOT_SEND_MESSAGE = -105,
+  SPLT_FREEDB_ERROR_INVALID_SERVER_ANSWER = -106,
+  SPLT_FREEDB_ERROR_SITE_201 = -107,
+  SPLT_FREEDB_ERROR_SITE_200 = -108,
+  SPLT_FREEDB_ERROR_BAD_COMMUNICATION = -109,
+  SPLT_FREEDB_ERROR_GETTING_INFOS = -110,
+  SPLT_FREEDB_NO_CD_FOUND = -111,
+  SPLT_FREEDB_ERROR_CANNOT_RECV_MESSAGE = -112,
+  SPLT_INVALID_CUE_FILE = -115,
+  SPLT_INVALID_CDDB_FILE = -116,
+  SPLT_FREEDB_NO_SUCH_CD_IN_DATABASE = -118,
+  SPLT_FREEDB_ERROR_SITE = -119,
 
-//miscellaneous error messages
-#define SPLT_ERROR_INEXISTENT_SPLITPOINT -500
+  SPLT_DEWRAP_ERR_FILE_LENGTH = -200,
+  SPLT_DEWRAP_ERR_VERSION_OLD = -201,
+  SPLT_DEWRAP_ERR_NO_FILE_OR_BAD_INDEX = -202,
+  SPLT_DEWRAP_ERR_FILE_DAMAGED_INCOMPLETE = -203,
+  SPLT_DEWRAP_ERR_FILE_NOT_WRAPED_DAMAGED = -204,
 
-//plugin error messages
-#define SPLT_PLUGIN_ERROR_UNSUPPORTED_FEATURE -600
+  SPLT_OUTPUT_FORMAT_ERROR = -400,
+
+  SPLT_ERROR_INEXISTENT_SPLITPOINT = -500,
+
+  SPLT_PLUGIN_ERROR_UNSUPPORTED_FEATURE = -600,
+
+  SPLT_INVALID_AUDACITY_FILE = -700,
+} splt_code;
 
 //internal
 #define SPLT_INTERNAL_PROGRESS_RATE 1
@@ -1045,7 +873,7 @@ typedef enum {
   SPLT_PROGRESS_SCAN_SILENCE
 } splt_progress_messages;
 
-//options types : integer
+//options types: integer
 /**
  * @brief Integer options
  *
@@ -1056,7 +884,7 @@ typedef enum {
  */
 typedef enum {
   /**
-   * Pretend to split the file, without real split : this option works in
+   * Pretend to split the file, without real split: this option works in
    * all modes except error mode and dewrap split.
    */
   SPLT_OPT_PRETEND_TO_SPLIT,
@@ -1123,7 +951,7 @@ typedef enum {
   /**
    * If we use silence detection to auto-adjust splitpoints\n
    * The following options may change the behaviour of the
-   * auto-adjust : #SPLT_OPT_PARAM_THRESHOLD, #SPLT_OPT_PARAM_OFFSET,
+   * auto-adjust: #SPLT_OPT_PARAM_THRESHOLD, #SPLT_OPT_PARAM_OFFSET,
    * #SPLT_OPT_PARAM_GAP, #
    *
    * The option can take the values #SPLT_TRUE or #SPLT_FALSE
@@ -1184,10 +1012,18 @@ typedef enum {
   /**
    * if we force a tags version or not
    */
-  SPLT_OPT_FORCE_TAGS_VERSION
+  SPLT_OPT_FORCE_TAGS_VERSION,
+  /**
+   * number of files to split by equal time length
+   */
+  SPLT_OPT_LENGTH_SPLIT_FILE_NUMBER,
+  /**
+   *
+   */
+  SPLT_OPT_REPLACE_TAGS_IN_TAGS
 } splt_int_options;
 
-//options types : long
+//options types: long
 /**
  * @brief Integer options
  *
@@ -1203,7 +1039,7 @@ typedef enum {
   SPLT_OPT_OVERLAP_TIME
 } splt_long_options;
 
-//option types : float
+//option types: float
 /**
  * @brief Float options
  *
@@ -1315,7 +1151,7 @@ typedef enum {
 /**
  * @brief Package version
  */
-#define SPLT_PACKAGE_VERSION "0.5.6"
+#define SPLT_PACKAGE_VERSION "0.5.9"
 #endif
 /**
  * @brief Package authors
@@ -1329,6 +1165,8 @@ typedef enum {
 
 /* other useful variables */
 
+#define MP3SPLT_LIB_GETTEXT_DOMAIN "libmp3splt"
+
 //backslash character
 #ifndef SPLT_DIRCHAR
 #ifdef __WIN32__
@@ -1386,8 +1224,8 @@ int mp3splt_set_silence_log_filename(splt_state *state, const char *filename);
 /************************************/
 /* Set callback functions           */
 
-int mp3splt_set_message_function(splt_state *state,
-    void (*put_message)(const char *));
+int mp3splt_set_message_function(splt_state *state, 
+    void (*message_cb)(const char *, splt_message_type));
 int mp3splt_set_split_filename_function(splt_state *state,
     void (*file_cb)(const char *,int));
 int mp3splt_set_progress_function(splt_state *state,
@@ -1477,6 +1315,9 @@ void mp3splt_put_cue_splitpoints_from_file(splt_state *state,
 void mp3splt_put_cddb_splitpoints_from_file(splt_state *state,
     const char *cddb_file, int *error);
 
+void mp3splt_put_audacity_labels_splitpoints_from_file(splt_state *state,
+    const char *file, int *error);
+
 /************************************/
 /*    Freedb functions              */
 
@@ -1499,6 +1340,9 @@ void mp3splt_write_freedb_file_result(splt_state *state,
     const char *cddb_get_server,
     int port);
 
+void mp3splt_export_to_cue(splt_state *state, const char *out_file,
+    short stop_at_total_time, int *error);
+
 void mp3splt_set_oformat(splt_state *state,
     const char *format_string, int *error);
 
@@ -1530,6 +1374,11 @@ int mp3splt_append_plugins_scan_dir(splt_state *state, char *dir);
 char *mp3splt_win32_utf16_to_utf8(const wchar_t *source);
 #endif
 
+char **mp3splt_find_filenames(splt_state *state, const char *filename,
+    int *num_of_files_found, int *error);
+
+int mp3splt_u_check_if_directory(const char *fname);
+
 #define MP3SPLT_MP3SPLT_H
 
 #endif
