@@ -4,7 +4,7 @@
  *               for mp3/ogg splitting without decoding
  *
  * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
- * Copyright (c) 2005-2009 Alexandru Munteanu - io_fx@yahoo.fr
+ * Copyright (c) 2005-2010 Alexandru Munteanu - io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net
  *
@@ -33,11 +33,12 @@
 float splt_p_get_version(splt_state *state, int *error);
 const char *splt_p_get_name(splt_state *state, int *error);
 const char *splt_p_get_extension(splt_state *state, int *error);
+const char *splt_p_get_upper_extension(splt_state *state, int *error);
 int splt_p_check_plugin_is_for_file(splt_state *state, int *error);
 void splt_p_search_syncerrors(splt_state *state, int *error);
 void splt_p_dewrap(splt_state *state, int listonly, const char *dir, int *error);
 void splt_p_set_total_time(splt_state *state, int *error);
-void splt_p_split(splt_state *state, const char *final_fname, double begin_point,
+double splt_p_split(splt_state *state, const char *final_fname, double begin_point,
     double end_point, int *error, int save_end_point);
 int splt_p_simple_split(splt_state *state, const char *output_fname, off_t begin,
     off_t end);
