@@ -4,7 +4,7 @@
  *               for mp3/ogg splitting without decoding
  *
  * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
- * Copyright (c) 2005-2009 Alexandru Munteanu - io_fx@yahoo.fr
+ * Copyright (c) 2005-2010 Alexandru Munteanu - io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net
  *
@@ -37,7 +37,6 @@
 
 #ifdef __WIN32__
 #include "windows.h"
-#include "io.h"
 #endif
 
 /****************************/
@@ -84,7 +83,7 @@ void splt_check_splitpts_inf_song_length(splt_state *state, int *error)
   }
 }
 
-//checks if splitpoints are in order : 1, 5, 6 ...
+//checks if splitpoints are in order: 1, 5, 6 ...
 //and not 1, 5, 4 ... (4<5 -> error)
 void splt_check_if_splitpoints_in_order(splt_state *state, int *error)
 {
@@ -114,7 +113,7 @@ void splt_check_if_splitpoints_in_order(splt_state *state, int *error)
       //we take the total time and assign it to split_value
       if (splitpoint_value == LONG_MAX)
       {
-        splt_t_set_splitpoint_value(state,i,splt_t_get_total_time(state));
+        splt_t_set_splitpoint_value(state, i, splt_t_get_total_time(state));
       }
 
       //check if splitpoints not in order
@@ -146,7 +145,7 @@ void splt_check_if_splitpoints_in_order(splt_state *state, int *error)
 void splt_check_if_new_filename_path_correct(splt_state *state,
     const char *new_filename_path, int *error)
 {
-  splt_u_print_debug("We check if the new filename path is correct ",0,new_filename_path);
+  splt_u_print_debug(state,"We check if the new filename path is correct ",0,new_filename_path);
 
   char current_directory[4] = { '\0' };
   snprintf(current_directory,4,"%c%c",'.',SPLT_DIRCHAR);
@@ -156,27 +155,12 @@ void splt_check_if_new_filename_path_correct(splt_state *state,
   if ((strcmp(new_filename_path, "") != 0) &&
       (strcmp(new_filename_path, current_directory) != 0))
   {
-    mode_t st_mode;
-    int status = splt_u_stat(new_filename_path, &st_mode, NULL);
-    if(status == -1)
+    if (!splt_io_check_if_directory(new_filename_path))
     {
-      splt_t_set_strerror_msg(state);
+      splt_t_set_strerr_msg(state, _("directory does not exists"));
       splt_t_set_error_data(state, new_filename_path);
       *error = SPLT_ERROR_INCORRECT_PATH;
     }
-    else
-    {
-      if (S_ISDIR(st_mode) != 0)
-      {
-        return;
-      }
-      else
-      {
-        splt_t_set_strerr_msg(state,"Directory does not exists");
-        splt_t_set_error_data(state, new_filename_path);
-        *error = SPLT_ERROR_INCORRECT_PATH;
-      }
-    }
   }
 }
 
@@ -263,7 +247,7 @@ int splt_check_compatible_options(splt_state *state)
 //we need so (this function is quite important)
 void splt_check_set_correct_options(splt_state *state)
 {
-  splt_u_print_debug("We check and set correct options.. ",0,NULL);
+  splt_u_print_debug(state,"We check and set correct options.. ",0,NULL);
 
   int split_mode = splt_t_get_int_option(state,SPLT_OPT_SPLIT_MODE);
 
@@ -331,10 +315,10 @@ void splt_check_file_type(splt_state *state, int *error)
 {
   int err = SPLT_OK;
 
-  splt_u_print_debug("Detecting file format...",0,NULL);
-  char *filename = splt_t_get_filename_to_split(state);
+  splt_u_print_debug(state,"Detecting file format...",0,NULL);
+  const char *filename = splt_t_get_filename_to_split(state);
 
-  splt_u_print_debug("Checking the format of",0,filename);
+  splt_u_print_debug(state,"Checking the format of",0,filename);
 
   //parse each plugin until we find out a plugin for the file
   splt_plugins *pl = state->plug;
@@ -344,25 +328,45 @@ void splt_check_file_type(splt_state *state, int *error)
   {
     splt_t_set_current_plugin(state, i);
     err = SPLT_OK;
-    if (splt_p_check_plugin_is_for_file(state, &err))
+
+    if (splt_t_get_int_option(state, SPLT_OPT_INPUT_NOT_SEEKABLE) &&
+        ! splt_t_is_stdin(state))
     {
+      const char *extension = splt_p_get_extension(state, &err);
+      const char *upper_extension = splt_p_get_extension(state, &err);
       if (err == SPLT_OK)
       {
-        //here, plugin found
-        plugin_found = SPLT_TRUE;
-        break;
+        if (splt_u_str_ends_with(filename, extension) ||
+            splt_u_str_ends_with(filename, upper_extension))
+        {
+          plugin_found = SPLT_TRUE;
+          break;
+        }
+      }
+    }
+    else
+    {
+      if (splt_p_check_plugin_is_for_file(state, &err))
+      {
+        if (err == SPLT_OK)
+        {
+          //here, plugin found
+          plugin_found = SPLT_TRUE;
+          break;
+        }
       }
     }
   }
+
   if (! plugin_found)
   {
     splt_t_set_error_data(state, filename);
     *error = SPLT_ERROR_NO_PLUGIN_FOUND_FOR_FILE;
-    splt_u_print_debug("No plugin found !",0,NULL);
+    splt_u_print_debug(state,"No plugin found !",0,NULL);
 
     //if no plugin was found,
     //verify if the file is a real file
-    splt_u_print_debug("Verify if the file is a file",0,filename);
+    splt_u_print_debug(state,"Verify if the file is a file",0,filename);
 
     FILE *test = NULL;
     if ((test = splt_u_fopen(filename,"r")) != NULL)
@@ -387,62 +391,6 @@ void splt_check_file_type(splt_state *state, int *error)
       return;
     }
   }
-  else
-  {
-    err = SPLT_OK;
-    const char *temp = splt_p_get_name(state,&err);
-    if (err != SPLT_OK)
-    {
-      char infos[2048] = { '\0' };
-      snprintf(infos,2048," info: file matches the plugin '%s'\n",temp);
-      splt_t_put_message_to_client(state, infos);
-    }
-    else
-    {
-      *error = err;
-      return;
-    }
-  }
-}
-
-//check if its a file
-//-we are not interested in errors
-int splt_check_is_file(splt_state *state, const char *fname)
-{
-  if (fname == NULL)
-  {
-    return SPLT_FALSE;
-  }
-  else
-  {
-    //stdin : consider as file
-    if (fname[strlen(fname)-1] == '-')
-    {
-      return SPLT_TRUE;
-    }
-
-    mode_t st_mode;
-    int status = splt_u_stat(fname, &st_mode, NULL);
-    if (status == 0)
-    {
-      if (S_ISREG(st_mode))
-      {
-        return SPLT_TRUE;
-      }
-      else
-      {
-        splt_t_set_strerror_msg(state);
-        splt_t_set_error_data(state, fname);
-        return SPLT_FALSE;
-      }
-    }
-    else
-    {
-      splt_t_set_strerror_msg(state);
-      splt_t_set_error_data(state, fname);
-      return SPLT_FALSE;
-    }
-  }
 }
 
 //close two filehandles
@@ -491,11 +439,11 @@ int splt_check_is_the_same_file(splt_state *state, const char *file1,
     return SPLT_FALSE;
   }
 
-  splt_u_print_debug("Checking if this file :",0,file1);
-  splt_u_print_debug("is like this file :",0,file2);
+  splt_u_print_debug(state,"Checking if this file:",0,file1);
+  splt_u_print_debug(state,"is like this file:",0,file2);
  
-  int is_file1 = splt_check_is_file(state, file1);
-  int is_file2 = splt_check_is_file(state, file2);
+  int is_file1 = splt_io_check_if_file(state, file1);
+  int is_file2 = splt_io_check_if_file(state, file2);
   if (is_file1 && is_file2)
   {
     //file1
