@@ -58,6 +58,12 @@ splt_state *mp3splt_new_state(int *error)
   }
   else
   {
+#ifndef __WIN32__
+    bindtextdomain(MP3SPLT_LIB_GETTEXT_DOMAIN, LOCALEDIR);
+#endif
+
+    bind_textdomain_codeset(MP3SPLT_LIB_GETTEXT_DOMAIN, "UTF-8");
+
     state = splt_t_new_state(state, err);
   }
 
@@ -226,7 +232,7 @@ int mp3splt_set_filename_to_split(splt_state *state, const char *filename)
 //sets the function that sends messages to the client
 //returns possible error
 int mp3splt_set_message_function(splt_state *state, 
-    void (*message_cb)(const char *))
+    void (*message_cb)(const char *, splt_message_type))
 {
   int error = SPLT_OK;
 
@@ -398,7 +404,7 @@ int mp3splt_append_tags(splt_state *state,
     {
       splt_t_lock_library(state);
 
-      error = splt_t_append_tags(state, title, artist,
+      error = splt_tu_append_tags(state, title, artist,
           album, performer, year, comment, track, genre);
 
       splt_t_unlock_library(state);
@@ -426,7 +432,7 @@ const splt_tags *mp3splt_get_tags(splt_state *state,
 
   if (state != NULL)
   {
-    return splt_t_get_tags(state,tags_number);
+    return splt_tu_get_tags(state,tags_number);
   }
   else
   {
@@ -479,7 +485,7 @@ void mp3splt_erase_all_tags(splt_state *state, int *error)
     {
       splt_t_lock_library(state);
 
-      splt_t_free_tags(state);
+      splt_tu_free_tags(state);
 
       splt_t_unlock_library(state);
     }
@@ -651,7 +657,6 @@ float mp3splt_get_float_option(splt_state *state, int option_name,
 //returns possible error
 int mp3splt_split(splt_state *state)
 {
-  //the result of the split
   int error = SPLT_OK;
 
   if (state != NULL)
@@ -660,7 +665,12 @@ int mp3splt_split(splt_state *state)
     {
       splt_t_lock_library(state);
 
-      splt_u_print_debug("Starting to split file...",0,NULL);
+      splt_u_print_debug(state,"Starting to split file...",0,NULL);
+
+      char *new_filename_path = NULL;
+      char *fname_to_split = splt_t_get_filename_to_split(state);
+
+      splt_u_print_debug(state,"Original filename/path to split is ",0, fname_to_split);
 
       if (splt_t_is_stdin(state))
       {
@@ -671,26 +681,35 @@ int mp3splt_split(splt_state *state)
 
       //we set default internal options
       splt_t_set_default_iopts(state);
- 
-      //the new filename path
-      char *new_filename_path = NULL;
-      char *fname_to_split = splt_t_get_filename_to_split(state);
-
-      splt_u_print_debug("Original filename to split is ",0, fname_to_split);
 
       //we put the real splitnumber in the splitnumber variable
       //that could be changed (see splitnumber in mp3splt.h)
       state->split.splitnumber = state->split.real_splitnumber;
       splt_t_set_current_split(state,0);
 
-      //we check if the filename is a real file
-      if (!splt_check_is_file(state, fname_to_split))
+      if (!splt_io_check_if_file(state, fname_to_split))
       {
         error = SPLT_ERROR_INEXISTENT_FILE;
         splt_t_unlock_library(state);
         return error;
       }
 
+#ifndef __WIN32__
+      char *linked_fname = splt_io_get_linked_fname(fname_to_split);
+      if (linked_fname)
+      {
+        char infos[2048] = { '\0' };
+        snprintf(infos, 2048, _(" info: resolving linked filename to '%s'\n"), linked_fname);
+        splt_t_put_info_message_to_client(state, infos);
+
+        splt_t_set_filename_to_split(state, linked_fname);
+        fname_to_split = splt_t_get_filename_to_split(state);
+
+        free(linked_fname);
+        linked_fname = NULL;
+      }
+#endif
+
       //if the new_filename_path is "", we put the directory of
       //the current song
       new_filename_path = splt_check_put_dir_of_cur_song(fname_to_split,
@@ -706,7 +725,7 @@ int mp3splt_split(splt_state *state)
 
       //if we have compatible options
       //this function is optional,
-      if (!splt_check_compatible_options(state))
+      if (! splt_check_compatible_options(state))
       {
         error = SPLT_ERROR_INCOMPATIBLE_OPTIONS;
         goto function_end;
@@ -732,22 +751,35 @@ int mp3splt_split(splt_state *state)
         if (error < 0) { goto function_end; }
       }
 
-      //we put the new filename path in the state
       splt_t_set_new_filename_path(state, new_filename_path, &error);
       if (error < 0) { goto function_end; }
 
-      //we create output directories if they do not exist
       error = splt_u_create_directories(state, new_filename_path);
       if (error < 0) { goto function_end; }
 
-      //check means the test is ok
       splt_check_if_new_filename_path_correct(state, new_filename_path, &error);
       if (error < 0) { goto function_end; }
 
+      if (splt_t_get_int_option(state, SPLT_OPT_TAGS) == SPLT_TAGS_ORIGINAL_FILE)
+      {
+        splt_u_put_tags_from_string(state, SPLT_ORIGINAL_TAGS_DEFAULT, &error);
+        if (error < 0)
+        {
+          splt_p_end(state, &error);
+          goto function_end;
+        }
+      }
+
       //we check if mp3 or ogg
       splt_check_file_type(state, &error);
       if (error < 0) { goto function_end; }
 
+      const char *plugin_name = splt_p_get_name(state,&error);
+      if (error < 0) { goto function_end; }
+      char infos[2048] = { '\0' };
+      snprintf(infos,2048,_(" info: file matches the plugin '%s'\n"), plugin_name);
+      splt_t_put_info_message_to_client(state, infos);
+
       //print the new m3u fname
       char *m3u_fname_with_path = splt_t_get_m3u_file_with_path(state, &error);
       if (error < 0) { goto function_end; }
@@ -756,9 +788,11 @@ int mp3splt_split(splt_state *state)
         int malloc_size = strlen(m3u_fname_with_path) + 200;
         char *mess = malloc(sizeof(char) * (strlen(m3u_fname_with_path) + 200));
         if (!mess) { error = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY; goto function_end; }
-        snprintf(mess, malloc_size, " M3U file '%s' will be created.\n",
+        snprintf(mess, malloc_size, _(" M3U file '%s' will be created.\n"),
             m3u_fname_with_path);
-        splt_t_put_message_to_client(state, mess);
+        splt_t_put_info_message_to_client(state, mess);
+        free(mess);
+        mess = NULL;
         free(m3u_fname_with_path);
         m3u_fname_with_path = NULL;
       }
@@ -767,18 +801,7 @@ int mp3splt_split(splt_state *state)
       splt_p_init(state, &error);
       if (error < 0) { goto function_end; }
 
-      splt_u_print_debug("Setting original tags...",0,NULL);
-      //we retrieve the original tags from the file
-      //and save them for future use
-      // (for use with the output options)
-      splt_t_get_original_tags(state,&error);
-      if (error < 0)
-      {
-        splt_p_end(state, &error);
-        goto function_end;
-      }
-
-      splt_u_print_debug("parse type of split...",0,NULL);
+      splt_u_print_debug(state,"parse type of split...",0,NULL);
 
       char message[1024] = { '\0' };
       //print Working with auto adjust if necessary
@@ -789,13 +812,13 @@ int mp3splt_split(splt_state *state)
             && (split_type != SPLT_OPTION_SILENCE_MODE)
             && (split_type != SPLT_OPTION_ERROR_MODE))
         {
-          snprintf(message, 1024, " Working with SILENCE AUTO-ADJUST (Threshold:"
-              " %.1f dB Gap: %d sec Offset: %.2f)\n",
+          snprintf(message, 1024, _(" Working with SILENCE AUTO-ADJUST (Threshold:"
+                " %.1f dB Gap: %d sec Offset: %.2f)\n"),
               splt_t_get_float_option(state, SPLT_OPT_PARAM_THRESHOLD),
               splt_t_get_int_option(state, SPLT_OPT_PARAM_GAP),
               splt_t_get_float_option(state, SPLT_OPT_PARAM_OFFSET));
 
-          splt_t_put_message_to_client(state, message);
+          splt_t_put_info_message_to_client(state, message);
         }
       }
 
@@ -811,6 +834,9 @@ int mp3splt_split(splt_state *state)
         case SPLT_OPTION_TIME_MODE:
           splt_s_time_split(state, &error);
           break;
+        case SPLT_OPTION_LENGTH_MODE:
+          splt_s_equal_length_split(state, &error);
+          break;
         case SPLT_OPTION_ERROR_MODE:
           splt_s_error_split(state, &error);
           break;
@@ -835,9 +861,11 @@ int mp3splt_split(splt_state *state)
       splt_p_end(state, &error);
 
 function_end:
-      //free memory
-      free(new_filename_path);
-      new_filename_path = NULL;
+      if (new_filename_path)
+      {
+        free(new_filename_path);
+        new_filename_path = NULL;
+      }
 
       splt_t_unlock_library(state);
     }
@@ -934,6 +962,34 @@ void mp3splt_put_cddb_splitpoints_from_file(splt_state *state,
   }
 }
 
+void mp3splt_put_audacity_labels_splitpoints_from_file(splt_state *state,
+    const char *file, int *error)
+{
+  int erro = SPLT_OK;
+  int *err = &erro;
+  if (error != NULL) { err = error; }
+
+  if (state != NULL)
+  {
+    if (!splt_t_library_locked(state))
+    {
+      splt_t_lock_library(state);
+
+      splt_audacity_put_splitpoints(file, state, err);
+
+      splt_t_unlock_library(state);
+    }
+    else
+    {
+      *err = SPLT_ERROR_LIBRARY_LOCKED;
+    }
+  }
+  else
+  {
+    *err = SPLT_ERROR_STATE_NULL;
+  }
+}
+
 /************************************/
 /*    Freedb functions              */
 
@@ -1018,31 +1074,33 @@ void mp3splt_write_freedb_file_result(splt_state *state, int disc_id,
       splt_t_lock_library(state);
 
       char *freedb_file_content = NULL;
-      freedb_file_content =
-        splt_freedb_get_file(state, disc_id, err,
-            cddb_get_type,cddb_get_server,port);
+      freedb_file_content = splt_freedb_get_file(state, disc_id, err,
+          cddb_get_type, cddb_get_server, port);
 
       //if no error, write file
       if (*err == SPLT_FREEDB_FILE_OK)
       {
-        //we write the result to the file
-        FILE *output = NULL;
-        if (!(output = splt_u_fopen(cddb_file, "w")))
+        if (! splt_t_get_int_option(state, SPLT_OPT_PRETEND_TO_SPLIT))
         {
-          splt_t_set_strerror_msg(state);
-          splt_t_set_error_data(state,cddb_file);
-          *err = SPLT_ERROR_CANT_WRITE_TO_OUTPUT_FILE;
-        }
-        else
-        {
-          fprintf(output,"%s",freedb_file_content);
-          if (fclose(output) != 0)
+          //we write the result to the file
+          FILE *output = NULL;
+          if (!(output = splt_u_fopen(cddb_file, "w")))
           {
             splt_t_set_strerror_msg(state);
-            splt_t_set_error_data(state, cddb_file);
-            *error = SPLT_ERROR_CANNOT_CLOSE_FILE;
+            splt_t_set_error_data(state,cddb_file);
+            *err = SPLT_ERROR_CANT_WRITE_TO_OUTPUT_FILE;
+          }
+          else
+          {
+            fprintf(output,"%s",freedb_file_content);
+            if (fclose(output) != 0)
+            {
+              splt_t_set_strerror_msg(state);
+              splt_t_set_error_data(state, cddb_file);
+              *err = SPLT_ERROR_CANNOT_CLOSE_FILE;
+            }
+            output = NULL;
           }
-          output = NULL;
         }
       }
 
@@ -1066,6 +1124,34 @@ void mp3splt_write_freedb_file_result(splt_state *state, int disc_id,
   }
 }
 
+void mp3splt_export_to_cue(splt_state *state, const char *out_file,
+    short stop_at_total_time, int *error)
+{
+  int erro = SPLT_OK;
+  int *err = &erro;
+  if (error != NULL) { err = error; }
+
+  if (state != NULL)
+  {
+    if (!splt_t_library_locked(state))
+    {
+      splt_t_lock_library(state);
+
+      splt_cue_export_to_file(state, out_file, stop_at_total_time, err);
+
+      splt_t_unlock_library(state);
+    }
+    else
+    {
+      *err = SPLT_ERROR_LIBRARY_LOCKED;
+    }
+  }
+  else
+  {
+    *err = SPLT_ERROR_STATE_NULL;
+  }
+}
+
 //puts output format
 void mp3splt_set_oformat(splt_state *state,
     const char *format_string, int *error)
@@ -1074,11 +1160,6 @@ void mp3splt_set_oformat(splt_state *state,
   int *err = &erro;
   if (error != NULL) { err = error; }
 
-  if (format_string == NULL)
-  {
-    return;
-  }
-
   if (state != NULL)
   {
     if (!splt_t_library_locked(state))
@@ -1292,3 +1373,90 @@ char *mp3splt_win32_utf16_to_utf8(const wchar_t *source)
 }
 #endif
 
+//returned result must be freed
+char **mp3splt_find_filenames(splt_state *state, const char *filename,
+    int *num_of_files_found, int *error)
+{
+  int erro = SPLT_OK;
+  int *err = &erro;
+  if (error != NULL) { err = error; }
+
+  char **found_files = NULL;
+
+  if (state != NULL)
+  {
+    if (!splt_t_library_locked(state))
+    {
+      splt_t_lock_library(state);
+
+      *num_of_files_found = 0;
+
+      if (splt_io_check_if_file(state, filename))
+      {
+        if (splt_u_file_is_supported_by_plugins(state, filename))
+        {
+          found_files = malloc(sizeof(char *));
+          if (!found_files)
+          {
+            *err = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+            return NULL;
+          }
+
+          int fname_size = strlen(filename) + 1;
+          found_files[0] = malloc(sizeof(char) * fname_size);
+          memset(found_files[0], '\0', fname_size);
+
+          if (!found_files[0])
+          {
+            free(found_files);
+            return NULL;
+          }
+
+          strncat(found_files[0], filename, fname_size);
+          *num_of_files_found = 1;
+        }
+      }
+      else
+      {
+        char *dir = strdup(filename);
+        if (dir == NULL)
+        {
+          *err = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+          return NULL;
+        }
+
+        if (dir[strlen(dir)-1] == SPLT_DIRCHAR)
+        {
+          dir[strlen(dir)-1] = '\0';
+        }
+
+        splt_u_find_filenames(state, dir, &found_files, num_of_files_found, err);
+
+        if (dir)
+        {
+          free(dir);
+          dir = NULL;
+        }
+      }
+
+      splt_t_unlock_library(state);
+    }
+    else
+    {
+      *err = SPLT_ERROR_LIBRARY_LOCKED;
+    }
+  }
+  else
+  {
+    *err = SPLT_ERROR_STATE_NULL;
+    return NULL;
+  }
+
+  return found_files;
+}
+
+int mp3splt_u_check_if_directory(const char *fname)
+{
+  return splt_io_check_if_directory(fname);
+}
+
