@@ -4,7 +4,7 @@
  *               for mp3/ogg splitting without decoding
  *
  * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
- * Copyright (c) 2005-2009 Alexandru Munteanu - io_fx@yahoo.fr
+ * Copyright (c) 2005-2010 Alexandru Munteanu - io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net
  *
@@ -39,128 +39,7 @@
 
 #ifdef __WIN32__
 #include <direct.h>
-#endif
-
-//mingw does not provide BSD functions 'scandir' and 'alphasort'
-#ifdef __WIN32__
-
-//-returns -1 for not enough memory, -2 for other errors
-//-a positive (or 0) number if success
-int scandir(const char *dir, struct _wdirent ***namelist,
-		int(*filter)(const struct _wdirent *),
-		int(*compar)(const struct _wdirent **, const struct _wdirent **))
-{
-  struct _wdirent **files = NULL;
-  struct _wdirent *file = NULL;
-  _WDIR *directory = NULL;
-  int number_of_files = 0;
-
-  wchar_t *wdir = splt_u_win32_utf8_to_utf16(dir);
-  directory = _wopendir(wdir);
-  if (wdir) { free(wdir); wdir = NULL; }
-  if (directory == NULL)
-  {
-    return -2;
-  }
-
-  int free_memory = 0;
-  int we_have_error = 0;
-
-  while ((file = _wreaddir(directory)))
-  {
-    if ((filter == NULL) || (filter(file)))
-    {
-      if (files == NULL)
-      {
-        files = malloc((sizeof *files));
-      }
-      else
-      {
-        files = realloc(files, (sizeof *files) * (number_of_files + 1));
-      }
-      if (files == NULL)
-      {
-        free_memory = 1;
-        we_have_error = 1;
-        break;
-      }
-
-      files[number_of_files] = malloc(sizeof(struct _wdirent));
-      if (files[number_of_files] == NULL)
-      {
-        free_memory = 1;
-        we_have_error = 1;
-        break;
-      }
-
-      *files[number_of_files] = *file;
-      number_of_files++;
-    }
-  }
-
-  //we should have a valid 'namelist' argument
-  if (namelist)
-  {
-    *namelist = files;
-  }
-  else
-  {
-    free_memory = 1;
-  }
-
-  //-free memory if error
-  if (free_memory)
-  {
-    while (number_of_files--)
-    {
-      if (files[number_of_files])
-      {
-        free(files[number_of_files]);
-        files[number_of_files] = NULL;
-      }
-    }
-    free(files);
-    files = NULL;
-  }
-
-  if (_wclosedir(directory) == -1)
-  {
-    return -2;
-  }
-
-  qsort(*namelist, number_of_files, sizeof **namelist,
-      (int (*)(const void *, const void *)) compar);
-
-  if (we_have_error)
-  {
-    return -1;
-  }
-
-  return number_of_files;
-}
-
-int alphasort(const struct _wdirent **a, const struct _wdirent **b)
-{
-  char *name_a = splt_u_win32_utf16_to_utf8((*a)->d_name);
-  char *name_b = splt_u_win32_utf16_to_utf8((*b)->d_name);
-
-  int ret = strcoll(name_a, name_b);
-
-  if (name_a)
-  {
-    free(name_a);
-    name_a = NULL;
-  }
-
-  if (name_b)
-  {
-    free(name_b);
-    name_b = NULL;
-  }
-
-  return ret;
-}
-
+#include "win32.h"
 #endif
 
 int splt_p_append_plugin_scan_dir(splt_state *state, char *dir)
@@ -225,19 +104,11 @@ int splt_p_set_default_plugins_scan_dirs(splt_state *state)
 }
 
 //function to filter the plugin files
-#ifdef __WIN32__
-static int splt_p_filter_plugin_files(const struct _wdirent *de)
-#else
 static int splt_p_filter_plugin_files(const struct dirent *de)
-#endif
 {
-#ifdef __WIN32__
-  char *file = splt_u_win32_utf16_to_utf8(de->d_name);
-#else
   char *file = (char *) de->d_name;
-#endif
-  char *p_end = NULL;
-  char *p_start = NULL;
+  const char *p_end = NULL;
+  const char *p_start = NULL;
   if (file)
   {
     if (strlen(file) >= 8)
@@ -245,40 +116,40 @@ static int splt_p_filter_plugin_files(const struct dirent *de)
       //if the name starts with splt_and contains .so or .sl or .dll or .dylib
       if (strncmp(file,"libsplt_",8) == 0)
       {
-        splt_u_print_debug("Looking at the file ",0, file);
-        //find the last '.' character
-        p_end = strrchr(file,'.');
+        splt_u_print_debug(NULL, "Looking at the file ",0, file);
+
         p_start = strchr(file,'.');
-        //we only look at files containing only one dot
+
+#ifndef __WIN32__
+        //gnu/linux .so.0
+        p_end = strstr(file, ".so.0");
+        if (p_end != NULL && (p_start == p_end) && (*(p_end+5) == '\0'))
+        {
+          return 1;
+        }
+#endif
+
+        p_end = strrchr(file,'.');
         if ((p_end != NULL) && (p_start == p_end))
         {
-          if ((strcmp(p_end,".so") == 0) ||
-              (strcmp(p_end,".sl") == 0) ||
-              (strcmp(p_end,".dll") == 0) ||
-              (strcmp(p_end,".dylib") == 0))
-          {
+          //windows .dll
 #ifdef __WIN32__
-            if (file)
-            {
-              free(file);
-              file = NULL;
-            }
-#endif
+          if (strcmp(p_end,".dll") == 0)
+          {
             return 1;
           }
+#else
+          //bsd .sl & darwin .dylib
+          if ((strcmp(p_end,".sl") == 0) || (strcmp(p_end,".dylib") == 0))
+          {
+            return 1;
+          }
+#endif
         }
       }
     }
   }
 
-#ifdef __WIN32__
-  if (file)
-  {
-    free(file);
-    file = NULL;
-  }
-#endif
-
   return 0;
 }
 
@@ -288,22 +159,20 @@ static int splt_p_scan_dir_for_plugins(splt_state *state, splt_plugins *pl, cons
 {
   int return_value = SPLT_OK;
 
-#ifdef __WIN32__
-  struct _wdirent **files = NULL;
-#else
   struct dirent **files = NULL;
-#endif
 
   int number_of_files = 0;
   //scan the directory
-  number_of_files = scandir(directory, &files, splt_p_filter_plugin_files,
-      alphasort);
+  number_of_files = scandir(directory, &files, splt_p_filter_plugin_files, alphasort);
   int directory_len = strlen(directory);
   int new_number_of_files = number_of_files;
 
   if (number_of_files == -1)
   {
-		return SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+    if (errno == ENOMEM)
+    {
+      return SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
+    }
   }
   else if (new_number_of_files >= 0)
   {
@@ -313,11 +182,7 @@ static int splt_p_scan_dir_for_plugins(splt_state *state, splt_plugins *pl, cons
     //copy their name
     while (new_number_of_files--)
     {
-#ifdef __WIN32__
-      fname = splt_u_win32_utf16_to_utf8(files[new_number_of_files]->d_name);
-#else
       fname = files[new_number_of_files]->d_name;
-#endif
       int fname_len = strlen(fname);
 
       //get the full directory + filename
@@ -366,6 +231,7 @@ static int splt_p_scan_dir_for_plugins(splt_state *state, splt_plugins *pl, cons
           goto end;
         }
         memset(pl->data[pl->number_of_plugins_found].func,0,sizeof(splt_plugin_func));
+
         pl->data[pl->number_of_plugins_found].plugin_filename = malloc(sizeof(char) *
             dir_and_fname_len);
         if (pl->data[pl->number_of_plugins_found].plugin_filename == NULL)
@@ -373,7 +239,8 @@ static int splt_p_scan_dir_for_plugins(splt_state *state, splt_plugins *pl, cons
           return_value = SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
           goto end;
         }
-        //set the plugin name and the directory
+
+        //set the plugin path
         snprintf(pl->data[pl->number_of_plugins_found].plugin_filename,
             dir_and_fname_len - 1,"%s%c%s",directory,SPLT_DIRCHAR,fname);
 
@@ -386,24 +253,9 @@ static int splt_p_scan_dir_for_plugins(splt_state *state, splt_plugins *pl, cons
         free(dir_and_fname);
         dir_and_fname = NULL;
       }
-
-#ifdef __WIN32__
-      if (fname)
-      {
-        free(fname);
-        fname = NULL;
-      }
-#endif
     }
 
 end:
-#ifdef __WIN32__
-    if (fname)
-    {
-      free(fname);
-      fname = NULL;
-    }
-#endif
     ;
 
     if (files)
@@ -445,13 +297,13 @@ static int splt_p_find_plugins(splt_state *state)
   {
     if (pl->plugins_scan_dirs[i] != NULL)
     {
-      splt_u_print_debug("Scanning plugins in the directory ",0, pl->plugins_scan_dirs[i]);
+      splt_u_print_debug(state,"Scanning plugins in the directory ",0, pl->plugins_scan_dirs[i]);
 
       //don't check if directory exists if the directory is ./ on unix-like
       //OSes or .\\ on windows
       if (((strlen(pl->plugins_scan_dirs[i]) >= 2) &&
             strncmp(pl->plugins_scan_dirs[i], current_dir,2) == 0) ||
-          splt_u_check_if_directory(pl->plugins_scan_dirs[i]))
+          splt_io_check_if_directory(pl->plugins_scan_dirs[i]))
       {
         return_value = splt_p_scan_dir_for_plugins(state, pl, pl->plugins_scan_dirs[i]);
         if (return_value != SPLT_OK)
@@ -469,14 +321,14 @@ int splt_p_move_replace_plugin_data(splt_state *state, int old, int new)
 {
   splt_plugins *pl = state->plug;
 
-  splt_t_free_plugin_data(pl->data[new]);
+  splt_t_free_plugin_data(&pl->data[new]);
 
   pl->data[new].func = malloc(sizeof(splt_plugin_func));
   if (pl->data[new].func == NULL)
   {
     return SPLT_ERROR_CANNOT_ALLOCATE_MEMORY;
   }
-  memcpy(pl->data[new].func, pl->data[old].func, sizeof(pl->data[old].func));
+  memset(pl->data[new].func,0,sizeof(splt_plugin_func));
 
   int plugin_fname_len = strlen(pl->data[old].plugin_filename) + 1;
   pl->data[new].plugin_filename = malloc(sizeof(char) * plugin_fname_len);
@@ -487,7 +339,7 @@ int splt_p_move_replace_plugin_data(splt_state *state, int old, int new)
   snprintf(pl->data[new].plugin_filename, plugin_fname_len, "%s",
       pl->data[old].plugin_filename);
 
-  splt_t_free_plugin_data(pl->data[old]);
+  splt_t_free_plugin_data(&pl->data[old]);
 
   return SPLT_OK;
 }
@@ -511,7 +363,7 @@ static int splt_p_shift_left_plugins_data(splt_state *state, int index)
 }
 
 //function that gets information of each plugin
-static int splt_p_open_get_plugins_data(splt_state *state)
+static int splt_p_open_get_valid_plugins(splt_state *state)
 {
   splt_plugins *pl = state->plug;
 
@@ -523,15 +375,15 @@ static int splt_p_open_get_plugins_data(splt_state *state)
   int i = 0;
   for (i = 0;i < pl->number_of_plugins_found;i++)
   {
-    splt_u_print_debug("\nTrying to open the plugin ...",0,pl->data[i].plugin_filename);
+    splt_u_print_debug(state,"\nTrying to open the plugin ...",0,pl->data[i].plugin_filename);
 
     //ltdl currently does not supports windows unicode path/filename
     pl->data[i].plugin_handle = lt_dlopen(pl->data[i].plugin_filename);
     //error
     if (! pl->data[i].plugin_handle)
     {
-      splt_u_print_debug("Error loading the plugin",0,pl->data[i].plugin_filename);
-      splt_u_print_debug(" - error message from libltdl : ",0,lt_dlerror());
+      splt_u_print_debug(state,"Error loading the plugin",0,pl->data[i].plugin_filename);
+      splt_u_print_debug(state," - error message from libltdl: ",0,lt_dlerror());
 
       //keep the index of this failed plugin in order to remove it
       //afterwards
@@ -548,40 +400,13 @@ static int splt_p_open_get_plugins_data(splt_state *state)
     }
     else
     {
-      splt_u_print_debug(" - success !",0,NULL);
+      splt_u_print_debug(state," - success !",0,NULL);
 
-      //get pointers to functions from the plugins
-      //-this function must only be called once and here 
-      *(void **) (&pl->data[i].func->check_plugin_is_for_file) =
-        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_check_plugin_is_for_file");
-      *(void **) (&pl->data[i].func->search_syncerrors) =
-        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_search_syncerrors");
-      *(void **) (&pl->data[i].func->dewrap) =
-        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_dewrap");
-      *(void **) (&pl->data[i].func->simple_split) =
-        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_simple_split");
-      *(void **) (&pl->data[i].func->split) =
-        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_split");
-      *(void **) (&pl->data[i].func->init) =
-        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_init");
-      *(void **) (&pl->data[i].func->end) =
-        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_end");
-      *(void **) (&pl->data[i].func->scan_silence) =
-        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_scan_silence");
-      *(void **) (&pl->data[i].func->set_original_tags) =
-        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_set_original_tags");
-      *(void **) (&pl->data[i].func->set_plugin_info) =
+      pl->data[i].func->set_plugin_info =
         lt_dlsym(pl->data[i].plugin_handle, "splt_pl_set_plugin_info");
       if (pl->data[i].func->set_plugin_info != NULL)
       {
         pl->data[i].func->set_plugin_info(&pl->data[i].info,&error);
-        /*splt_t_set_current_plugin(state, i);
-        const char *p_name = splt_p_get_name(state, &error);
-        fprintf(stdout," Plugin NAME = _%s_\n",p_name);
-        fflush(stdout);*/
-      }
-      else
-      {
       }
 
       //look if we already have a plugin with the same name
@@ -597,17 +422,31 @@ static int splt_p_open_get_plugins_data(splt_state *state)
           //if we do have one with the same name,
           if (strcmp(plugin_name,current_plugin_name) == 0)
           {
-            //keep its index to remove it afterwards
-            if (! plugin_index_to_remove)
+            //keep unique index to remove afterwards
+            int unique = SPLT_TRUE;
+            int k = 0;
+            for (k = 0;k < number_of_plugins_to_remove;k++)
             {
-              plugin_index_to_remove = malloc(sizeof(int));
+              if (i == plugin_index_to_remove[k])
+              {
+                unique = SPLT_FALSE;
+                break;
+              }
             }
-            else
+            if (unique)
             {
-              plugin_index_to_remove = realloc(plugin_index_to_remove, sizeof(int) * (number_of_plugins_to_remove + 1));
+              if (! plugin_index_to_remove)
+              {
+                plugin_index_to_remove = malloc(sizeof(int));
+              }
+              else
+              {
+                plugin_index_to_remove = realloc(plugin_index_to_remove,
+                    sizeof(int) * (number_of_plugins_to_remove + 1));
+              }
+              plugin_index_to_remove[number_of_plugins_to_remove] = i;
+              number_of_plugins_to_remove++;
             }
-            plugin_index_to_remove[number_of_plugins_to_remove] = i;
-            number_of_plugins_to_remove++;
           }
         }
       }
@@ -623,12 +462,20 @@ static int splt_p_open_get_plugins_data(splt_state *state)
   {
     int index_to_remove = plugin_index_to_remove[i] - left_shift;
 
-    splt_u_print_debug("Removing the plugin ",0, pl->data[index_to_remove].plugin_filename);
+    splt_u_print_debug(state,"Removing the plugin ",0,
+        pl->data[index_to_remove].plugin_filename);
 
-    error = splt_p_shift_left_plugins_data(state, index_to_remove);
-    if (error != SPLT_OK)
+    if (i == number_of_plugins_to_remove-1)
     {
-      goto end;
+      splt_t_free_plugin_data(&pl->data[index_to_remove]);
+    }
+    else
+    {
+      error = splt_p_shift_left_plugins_data(state, index_to_remove);
+      if (error != SPLT_OK)
+      {
+        goto end;
+      }
     }
 
     pl->number_of_plugins_found--;
@@ -654,7 +501,7 @@ int splt_p_find_get_plugins_data(splt_state *state)
 {
   int return_value = SPLT_OK;
 
-  splt_u_print_debug("\nSearching for plugins ...",0,NULL);
+  splt_u_print_debug(state,"\nSearching for plugins ...",0,NULL);
 
   //find the plugins
   return_value = splt_p_find_plugins(state);
@@ -666,31 +513,59 @@ int splt_p_find_get_plugins_data(splt_state *state)
   else
   {
     //open the plugins
-    return_value = splt_p_open_get_plugins_data(state);
+    return_value = splt_p_open_get_valid_plugins(state);
   }
 
   if (return_value >= 0)
   {
     //debug
     splt_plugins *pl = state->plug;
-    splt_u_print_debug("\nNumber of plugins found = ",pl->number_of_plugins_found,NULL);
-    splt_u_print_debug("",0,NULL);
+    splt_u_print_debug(state,"\nNumber of plugins found = ",pl->number_of_plugins_found,NULL);
+    splt_u_print_debug(state,"",0,NULL);
     int i = 0;
     int err = 0;
     for (i = 0;i < pl->number_of_plugins_found;i++)
     {
+      pl->data[i].plugin_handle = lt_dlopen(pl->data[i].plugin_filename);
+
+      pl->data[i].func->check_plugin_is_for_file =
+        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_check_plugin_is_for_file");
+      pl->data[i].func->search_syncerrors =
+        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_search_syncerrors");
+      pl->data[i].func->dewrap =
+        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_dewrap");
+      pl->data[i].func->simple_split =
+        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_simple_split");
+      pl->data[i].func->split =
+        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_split");
+      pl->data[i].func->init =
+        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_init");
+      pl->data[i].func->end =
+        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_end");
+      pl->data[i].func->scan_silence =
+        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_scan_silence");
+      pl->data[i].func->set_original_tags =
+        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_set_original_tags");
+      pl->data[i].func->set_plugin_info =
+        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_set_plugin_info");
+      if (pl->data[i].func->set_plugin_info != NULL)
+      {
+        splt_t_free_plugin_data_info(&pl->data[i]);
+        pl->data[i].func->set_plugin_info(&pl->data[i].info,&err);
+      }
+
       splt_t_set_current_plugin(state, i);
       if (pl->data[i].plugin_filename != NULL)
       {
-        splt_u_print_debug("plugin filename = ",0,pl->data[i].plugin_filename);
+        splt_u_print_debug(state,"plugin filename = ",0,pl->data[i].plugin_filename);
       }
       const char *temp = splt_p_get_name(state, &err);
-      splt_u_print_debug("plugin name = ",0,temp);
+      splt_u_print_debug(state,"plugin name = ",0,temp);
       float version = splt_p_get_version(state, &err);
-      splt_u_print_debug("plugin version = ", version, NULL);
+      splt_u_print_debug(state,"plugin version = ", version, NULL);
       temp = splt_p_get_extension(state,&err);
-      splt_u_print_debug("extension = ",0,temp);
-      splt_u_print_debug("",0,NULL);
+      splt_u_print_debug(state,"extension = ",0,temp);
+      splt_u_print_debug(state,"",0,NULL);
     }
   }
   splt_t_set_current_plugin(state, -1);
@@ -745,6 +620,21 @@ const char *splt_p_get_extension(splt_state *state, int *error)
   }
 }
 
+const char *splt_p_get_upper_extension(splt_state *state, int *error)
+{
+  splt_plugins *pl = state->plug;
+  int current_plugin = splt_t_get_current_plugin(state);
+  if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
+  {
+    *error = SPLT_ERROR_NO_PLUGIN_FOUND;
+    return NULL;
+  }
+  else
+  {
+    return pl->data[current_plugin].info.upper_extension;
+  }
+}
+
 /* plugin function wrappers */
 
 int splt_p_check_plugin_is_for_file(splt_state *state, int *error)
@@ -816,7 +706,7 @@ void splt_p_dewrap(splt_state *state, int listonly, const char *dir, int *error)
   }
 }
 
-void splt_p_split(splt_state *state, const char *final_fname, double begin_point,
+double splt_p_split(splt_state *state, const char *final_fname, double begin_point,
     double end_point, int *error, int save_end_point)
 {
   splt_plugins *pl = state->plug;
@@ -824,20 +714,30 @@ void splt_p_split(splt_state *state, const char *final_fname, double begin_point
   if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
   {
     *error = SPLT_ERROR_NO_PLUGIN_FOUND;
-    return;
+    return end_point;
   }
   else
   {
+    int err = SPLT_OK;
+    splt_u_create_output_dirs_if_necessary(state, final_fname, &err);
+    if (err < 0) { *error = err; return end_point; }
+
     if (pl->data[current_plugin].func->split != NULL)
     {
-      pl->data[current_plugin].func->split(state, final_fname,
+      double new_end_point = pl->data[current_plugin].func->split(state, final_fname,
           begin_point, end_point, error, save_end_point);
+
+      splt_u_print_debug(state, "New end point after split ...",new_end_point,NULL);
+
+      return new_end_point;
     }
     else
     {
       *error = SPLT_PLUGIN_ERROR_UNSUPPORTED_FEATURE;
     }
   }
+
+  return end_point;
 }
 
 void splt_p_init(splt_state *state, int *error)
@@ -884,7 +784,6 @@ void splt_p_end(splt_state *state, int *error)
   }
 }
 
-
 int splt_p_simple_split(splt_state *state, const char *output_fname, off_t begin,
     off_t end)
 {
