@@ -4,7 +4,7 @@
  *               for mp3/ogg splitting without decoding
  *
  * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
- * Copyright (c) 2005-2009 Alexandru Munteanu - io_fx@yahoo.fr
+ * Copyright (c) 2005-2010 Alexandru Munteanu - io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net
  *
@@ -40,55 +40,50 @@
 /* splt normal split */
 
 //the real split of the file
-static void splt_s_real_split(splt_state *state, int *error, int save_end_point)
+static long splt_s_real_split(splt_state *state, int *error, int save_end_point)
 {
   double splt_beg = splt_t_get_i_begin_point(state);
   double splt_end = splt_t_get_i_end_point(state);
-  char *final_fname = NULL;
-  final_fname = splt_u_get_fname_with_path_and_extension(state,error);
+  char *final_fname = splt_u_get_fname_with_path_and_extension(state,error);
+  long new_end_point = splt_u_time_to_long_ceil(splt_end);
 
   if (*error >= 0)
   {
-    if (!splt_t_get_int_option(state, SPLT_OPT_PRETEND_TO_SPLIT))
-    {
+    double new_sec_end_point = 
       splt_p_split(state, final_fname, splt_beg, splt_end, error, save_end_point);
+    new_end_point = splt_u_time_to_long_ceil(new_sec_end_point);
 
-      //if no error
-      if (*error >= 0)
-      {
-        //automatically set progress callback to 100%
-        splt_t_update_progress(state,1.0,1.0,1,1,1);
+    //if no error
+    if (*error >= 0)
+    {
+      //automatically set progress callback to 100%
+      splt_t_update_progress(state,1.0,1.0,1,1,1);
 
-        //we put the split file
-        int err = SPLT_OK;
-        err = splt_t_put_split_file(state, final_fname);
-        if (err < 0) { *error = err; }
-      }
+      //we put the split file
+      int err = SPLT_OK;
+      err = splt_t_put_split_file(state, final_fname);
+      if (err < 0) { *error = err; }
     }
   }
 
   if (final_fname)
   {
-    //free memory
     free(final_fname);
     final_fname = NULL;
   }
+
+  return new_end_point;
 }
 
-//simple split with only 2 splitpoints
-static void splt_s_split(splt_state *state, int first_splitpoint,
+static long splt_s_split(splt_state *state, int first_splitpoint,
     int second_splitpoint, int *error)
 {
-  //begin splitpoint
-  double splt_beg = 0;
-  //end splitpoint
-  double splt_end = 0;
-
-  //we get the splitpoints to split
   int get_error = SPLT_OK;
-  long split_begin = 0,split_end = 0;
-  split_begin = splt_t_get_splitpoint_value(state, first_splitpoint, &get_error);
-  split_end = splt_t_get_splitpoint_value(state, second_splitpoint, &get_error);
+  long split_begin = splt_t_get_splitpoint_value(state, first_splitpoint, &get_error);
+  long split_end = splt_t_get_splitpoint_value(state, second_splitpoint, &get_error);
+
+  long new_end_point = split_end;
+
   int save_end_point = SPLT_TRUE;
   if (splt_t_get_splitpoint_type(state, second_splitpoint, &get_error) == SPLT_SKIPPOINT ||
       splt_t_get_long_option(state, SPLT_OPT_OVERLAP_TIME) > 0)
@@ -106,13 +101,15 @@ static void splt_s_split(splt_state *state, int first_splitpoint,
       {
         //convert to float for hundredth
         // 34.6  --> 34 seconds and 6 hundredth
-        splt_beg = split_begin / 100;
+        double splt_beg = split_begin / 100;
         splt_beg += ((split_begin % 100) / 100.);
-        //we will transmit to the plugins the -1.f value
-        //if we have LONG_MAX (== EOF)
+        double splt_end = 0;
+
+        //LONG_MAX == EOF
         if (split_end == LONG_MAX)
         {
-          splt_end = -1.f;
+          //Warning : we might not always have total time with input not seekable
+          splt_end = splt_t_get_total_time_as_double_secs(state);
         }
         else
         {
@@ -123,8 +120,7 @@ static void splt_s_split(splt_state *state, int first_splitpoint,
         splt_t_set_i_begin_point(state, splt_beg);
         splt_t_set_i_end_point(state, splt_end);
 
-        //we do the real split
-        splt_s_real_split(state, error, save_end_point);
+        new_end_point = splt_s_real_split(state, error, save_end_point);
       }
       else
       {
@@ -137,66 +133,60 @@ static void splt_s_split(splt_state *state, int first_splitpoint,
   {
     *error = get_error;
   }
+
+  return new_end_point;
 }
 
 //splits the file with multiple points
 void splt_s_multiple_split(splt_state *state, int *error)
 {
   int split_type = splt_t_get_int_option(state, SPLT_OPT_SPLIT_MODE);
-
-  int i = 0;
-
   int err = SPLT_OK;
 
   splt_t_set_oformat_digits(state);
 
   if (split_type == SPLT_OPTION_NORMAL_MODE)
   {
-    splt_t_put_message_to_client(state, " info: starting normal split\n");
+    splt_t_put_info_message_to_client(state, _(" info: starting normal split\n"));
   }
 
   splt_u_print_overlap_time(state);
 
   int get_error = SPLT_OK;
 
-  //for every 2 splitpoints, split
+  splt_array *new_end_points = splt_array_new();
+
+  int i = 0;
   int number_of_splitpoints = splt_t_get_splitnumber(state);
   while (i  < number_of_splitpoints - 1)
   {
-    //we put the current file to split
     splt_t_set_current_split(state, i);
 
-    splt_t_auto_increment_tracknumber_tag(state);
-
-    //if we don't cancel the split
     if (!splt_t_split_is_canceled(state))
     {
       get_error = SPLT_OK;
 
-      long saved_end_point = splt_t_get_splitpoint_value(state, i+1, &get_error);
-      splt_u_overlap_time(state, i+1);
-
-      if (splt_t_get_int_option(state, SPLT_OPT_TAGS) == SPLT_TAGS_ORIGINAL_FILE)
-      {
-        err = splt_t_append_original_tags(state);
-        if (err < 0) { *error = err; return; }
-      }
-
-      err = splt_u_put_output_format_filename(state);
-      if (err < 0) { *error = err; return; }
-
       int first_splitpoint_type = splt_t_get_splitpoint_type(state, i, &get_error);
       if (first_splitpoint_type == SPLT_SKIPPOINT)
       {
+        splt_u_print_debug(state, "SKIP splitpoint", i, NULL);
         i++;
         continue;
       }
 
-      splt_s_split(state, i, i+1, error);
+      splt_tu_auto_increment_tracknumber(state);
 
-      splt_t_set_splitpoint_value(state, i+1,saved_end_point);
+      long saved_end_point = splt_t_get_splitpoint_value(state, i+1, &get_error);
+      splt_u_overlap_time(state, i+1);
+
+      err = splt_u_finish_tags_and_put_output_format_filename(state, i);
+      if (err < 0) { *error = err; goto end; }
+
+      long new_end_point = splt_s_split(state, i, i+1, error);
+      splt_array_append(new_end_points, (void *)new_end_point);
+
+      splt_t_set_splitpoint_value(state, i+1, saved_end_point);
 
-      //get out if error
       if ((*error < 0) || (*error == SPLT_OK_SPLIT_EOF))
       {
         break;
@@ -205,10 +195,20 @@ void splt_s_multiple_split(splt_state *state, int *error)
     else
     {
       *error = SPLT_SPLIT_CANCELLED;
-      return;
+      goto end;
     }
+
     i++;
   }
+
+end:
+  for (i = 0;i < splt_array_length(new_end_points);i++)
+  {
+    splt_t_set_splitpoint_value(state, i+1,
+        (long) splt_array_get(new_end_points, i));
+  }
+
+  splt_array_free(&new_end_points);
 }
 
 void splt_s_normal_split(splt_state *state, int *error)
@@ -226,7 +226,7 @@ void splt_s_normal_split(splt_state *state, int *error)
 //the sync error mode
 void splt_s_error_split(splt_state *state, int *error)
 {
-  splt_t_put_message_to_client(state, " info: starting error mode split\n");
+  splt_t_put_info_message_to_client(state, _(" info: starting error mode split\n"));
   char *final_fname = NULL;
 
   //we detect sync errors
@@ -262,29 +262,26 @@ void splt_s_error_split(splt_state *state, int *error)
         //we put the current file to split
         splt_t_set_current_split(state, i);
 
-        splt_t_auto_increment_tracknumber_tag(state);
+        splt_tu_auto_increment_tracknumber(state);
 
         //we append a splitpoint
         int err = splt_t_append_splitpoint(state, 0, "", SPLT_SPLITPOINT);
         if (err < 0) { *error = err; goto bloc_end; }
 
-        //if we have to put the original tags
-        if (splt_t_get_int_option(state, SPLT_OPT_TAGS) == SPLT_TAGS_ORIGINAL_FILE)
-        {
-          //we put the original tags to the current split
-          err = splt_t_append_original_tags(state);
-          if (err < 0) { *error = err; goto bloc_end; }
-        }
-
-        //we put the output filename
-        err = splt_u_put_output_format_filename(state);
+        err = splt_u_finish_tags_and_put_output_format_filename(state, -1);
         if (err < 0) { *error = err; goto bloc_end; }
 
         //we get the final fname
         final_fname = splt_u_get_fname_with_path_and_extension(state, error);
 
-        if(*error >= 0)
+        if (*error >= 0)
         {
+          splt_u_create_output_dirs_if_necessary(state, final_fname, error);
+          if (error < 0)
+          {
+            goto bloc_end;
+          }
+
           //we split with the detected splitpoints
           int split_result = splt_p_simple_split(state, final_fname, 
               (off_t) state->serrors->serrors_points[i], 
@@ -297,6 +294,10 @@ void splt_s_error_split(splt_state *state, int *error)
           {
             *error = SPLT_SYNC_OK;
           }
+          else
+          {
+            *error = split_result;
+          }
 
           //if the split has been a success
           if (*error == SPLT_SYNC_OK)
@@ -344,38 +345,29 @@ bloc_end:
 }
 
 /************************************/
-/* splt time split */
+/* splt time and length split */
 
-//function used with the -t option (time split
-//create an indefinite number of smaller files with a fixed time
-//length specified by options.split_time in seconds
-void splt_s_time_split(splt_state *state, int *error)
+static void splt_s_split_by_time(splt_state *state, int *error,
+    double split_time_length, int number_of_files)
 {
-  splt_u_print_debug("Starting time split...",0,NULL);
-  splt_t_put_message_to_client(state, " info: starting time mode split\n");
-
-  splt_u_print_overlap_time(state);
-
   char *final_fname = NULL;
-  //if the state has an error
-  int j=0,tracks=1;
-  //the begin split
+  int j=0, tracks=1;
   double begin = 0.f;
-  double end = (double) splt_t_get_float_option(state, SPLT_OPT_SPLIT_TIME);
-  if (end == 0.0)
-  {
-    *error = SPLT_ERROR_TIME_SPLIT_VALUE_INVALID;
-    return;
-  }
+  double end = split_time_length;
+  long total_time = splt_t_get_total_time(state);
 
-  //if no state error
-  if (end >= 0)
+  if (split_time_length >= 0)
   {
+    splt_u_print_overlap_time(state);
+
     int err = SPLT_OK;
 
-    int temp_int = (int)floor(((splt_t_get_total_time(state)/100.0) /
-          (state->options.split_time))+1) + 1;
-    splt_t_set_splitnumber(state,temp_int);
+    int temp_int = number_of_files + 1;
+    if (number_of_files == -1)
+    {
+      temp_int = (int)floor(((total_time / 100.0) / (split_time_length))+1) + 1;
+    }
+    splt_t_set_splitnumber(state, temp_int);
 
     splt_t_set_oformat_digits(state);
 
@@ -399,68 +391,56 @@ void splt_s_time_split(splt_state *state, int *error)
 
       int last_file = SPLT_FALSE;
 
-      //while we have tracks
+      splt_array *new_end_points = splt_array_new();
+
       do {
-        //if we don't cancel the split
         if (!splt_t_split_is_canceled(state))
         {
-          //we append a splitpoint
           err = splt_t_append_splitpoint(state, 0, "", SPLT_SPLITPOINT);
           if (err < 0) { *error = err; break; }
 
-          //if we have to put the original tags
-          if (splt_t_get_int_option(state, SPLT_OPT_TAGS) == SPLT_TAGS_ORIGINAL_FILE)
-          {
-            //we put the original tags to the current split
-            err = splt_t_append_original_tags(state);
-            if (err < 0) { *error = err; break; }
-          }
-
-          //we set the current split
           splt_t_set_current_split(state, tracks-1);
 
-          splt_t_auto_increment_tracknumber_tag(state);
+          splt_tu_auto_increment_tracknumber(state);
 
           int current_split = splt_t_get_current_split(state);
 
-          //we put the splitpoints values in the state
-          splt_t_set_splitpoint_value(state, current_split,(long)(begin*100));
-          long end_splitpoint = end*100;
-          if (end_splitpoint > splt_t_get_total_time(state))
+          splt_t_set_splitpoint_value(state, current_split,
+              splt_u_time_to_long_ceil(begin));
+          long end_splitpoint = splt_u_time_to_long_ceil(end);
+          if (total_time > 0 && end_splitpoint >= total_time)
           {
-            end_splitpoint = splt_t_get_total_time(state);
-            //avoid worst scenarios where floor & SPLT_OK_SPLIT_EOF do not
-            //work
+            end_splitpoint = total_time;
+            //avoid worst scenarios where floor & SPLT_OK_SPLIT_EOF do not work
             last_file = SPLT_TRUE;
           }
-          splt_t_set_splitpoint_value(state, current_split+1,end_splitpoint);
+          splt_t_set_splitpoint_value(state, current_split+1, end_splitpoint);
 
-          double overlapped_end =
-            (double)(splt_u_overlap_time(state, current_split+1) / 100.0);
+          double overlapped_end = (double)
+            ((double)splt_u_overlap_time(state, current_split+1) / 100.0);
 
-          err = splt_u_put_output_format_filename(state);
+          err = splt_u_finish_tags_and_put_output_format_filename(state, -1);
           if (err < 0) { *error = err; break; }
 
-          if (!splt_t_get_int_option(state, SPLT_OPT_PRETEND_TO_SPLIT))
+          //we get the final fname
+          final_fname = splt_u_get_fname_with_path_and_extension(state,&err);
+          if (err < 0) { *error = err; break; }
+
+          double new_sec_end_point = splt_p_split(state, final_fname,
+              begin, overlapped_end, error, save_end_point);
+          long new_end_point = splt_u_time_to_long_ceil(new_sec_end_point);
+          splt_array_append(new_end_points, (void *) new_end_point);
+
+          //if no error for the split, put the split file
+          if (*error >= 0)
           {
-            //we get the final fname
-            final_fname = splt_u_get_fname_with_path_and_extension(state,&err);
+            err = splt_t_put_split_file(state, final_fname);
             if (err < 0) { *error = err; break; }
-
-            splt_p_split(state, final_fname, begin, overlapped_end,
-                error, save_end_point);
-
-            //if no error for the split, put the split file
-            if (*error >= 0)
-            {
-              err = splt_t_put_split_file(state, final_fname);
-              if (err < 0) { *error = err; break; }
-            }
           }
 
           //set new splitpoints
           begin = end;
-          end += splt_t_get_float_option(state,SPLT_OPT_SPLIT_TIME);
+          end += split_time_length;
           tracks++;
 
           //get out if error
@@ -496,12 +476,19 @@ void splt_s_time_split(splt_state *state, int *error)
 
       } while (j++<tracks);
 
-      //free memory if returned with 'break' from the previous 'while'
       if (final_fname)
       {
         free(final_fname);
         final_fname = NULL;
       }
+
+      int i = 0;
+      for (i = 0;i < splt_array_length(new_end_points);i++)
+      {
+        splt_t_set_splitpoint_value(state, i+1,
+            (long) splt_array_get(new_end_points, i));
+      }
+      splt_array_free(&new_end_points);
     }
     else
     {
@@ -511,16 +498,16 @@ void splt_s_time_split(splt_state *state, int *error)
     //we put the time split error
     switch (*error)
     {
-      case SPLT_MIGHT_BE_VBR : 
+      case SPLT_MIGHT_BE_VBR: 
         *error = SPLT_TIME_SPLIT_OK;
         break;
       case SPLT_OK_SPLIT: 
         *error = SPLT_TIME_SPLIT_OK;
         break;
-      case SPLT_OK_SPLIT_EOF : 
+      case SPLT_OK_SPLIT_EOF: 
         *error = SPLT_TIME_SPLIT_OK;
         break;
-      case SPLT_ERROR_BEGIN_OUT_OF_FILE : 
+      case SPLT_ERROR_BEGIN_OUT_OF_FILE: 
         *error = SPLT_TIME_SPLIT_OK;
         break;
       default:
@@ -533,6 +520,59 @@ void splt_s_time_split(splt_state *state, int *error)
   }
 }
 
+//function used with the -t option (time split
+//create an indefinite number of smaller files with a fixed time
+//length specified by options.split_time in seconds
+void splt_s_time_split(splt_state *state, int *error)
+{
+  splt_t_put_info_message_to_client(state, _(" info: starting time mode split\n"));
+
+  double split_time_length = (double) splt_t_get_float_option(state, SPLT_OPT_SPLIT_TIME);
+  if (((long)split_time_length) == 0)
+  {
+    *error = SPLT_ERROR_TIME_SPLIT_VALUE_INVALID;
+    return;
+  }
+
+  splt_s_split_by_time(state, error, split_time_length, -1);
+}
+
+//function used with the -L option (length split
+//split into X files
+//X is defined by SPLT_OPT_LENGTH_SPLIT_FILE_NUMBER
+void splt_s_equal_length_split(splt_state *state, int *error)
+{
+  splt_t_put_info_message_to_client(state, _(" info: starting 'split in equal tracks' mode\n"));
+
+  double total_time = splt_t_get_total_time_as_double_secs(state);
+  if (total_time > 0)
+  {
+    int number_of_files =
+      splt_t_get_int_option(state, SPLT_OPT_LENGTH_SPLIT_FILE_NUMBER);
+
+    if (number_of_files > 0)
+    {
+      double split_time_length = total_time / number_of_files;
+      splt_s_split_by_time(state, error, split_time_length, number_of_files);
+    }
+    else
+    {
+      *error = SPLT_ERROR_LENGTH_SPLIT_VALUE_INVALID;
+      return;
+    }
+  }
+  else
+  {
+    *error = SPLT_ERROR_CANNOT_GET_TOTAL_TIME;
+    return;
+  }
+
+  if (*error == SPLT_TIME_SPLIT_OK)
+  {
+    *error = SPLT_LENGTH_SPLIT_OK;
+  }
+}
+
 /************************************/
 /* splt silence detection and split */
 
@@ -541,10 +581,11 @@ void splt_s_time_split(splt_state *state, int *error)
 //sets the silence splitpoints in state->split.splitpoints
 int splt_s_set_silence_splitpoints(splt_state *state, int *error)
 {
-  splt_u_print_debug("We search and set silence splitpoints...",0,NULL);
+  splt_u_print_debug(state,"We search and set silence splitpoints...",0,NULL);
 
   //found is the number of silence splits found
   int found = 0;
+  int splitpoints_appended = 0;
   struct splt_ssplit *temp = NULL;
   int append_error = SPLT_OK;
   //we get some options
@@ -597,33 +638,33 @@ int splt_s_set_silence_splitpoints(splt_state *state, int *error)
   char remove_str[128] = { '\0' };
   if (splt_t_get_int_option(state, SPLT_OPT_PARAM_REMOVE_SILENCE))
   {
-    snprintf(remove_str,128,"YES");
+    snprintf(remove_str,128,_("YES"));
   }
   else
   {
-    snprintf(remove_str,128,"NO");
+    snprintf(remove_str,128,_("NO"));
   }
   char auto_user_str[128] = { '\0' };
   if (splt_t_get_int_option(state, SPLT_OPT_PARAM_NUMBER_TRACKS) > 0)
   {
-    snprintf(auto_user_str,128,"User");
+    snprintf(auto_user_str,128,_("User"));
   }
   else
   {
-    snprintf(auto_user_str,128,"Auto");
+    snprintf(auto_user_str,128,_("Auto"));
   }
 
   char message[1024] = { '\0' };
   if (! splt_t_get_int_option(state,SPLT_OPT_QUIET_MODE))
   {
-    snprintf(message, 1024, " Silence split type: %s mode (Th: %.1f dB,"
-        " Off: %.2f, Min: %.2f, Remove: %s)\n",
+    snprintf(message, 1024, _(" Silence split type: %s mode (Th: %.1f dB,"
+          " Off: %.2f, Min: %.2f, Remove: %s)\n"),
         auto_user_str,
         splt_t_get_float_option(state, SPLT_OPT_PARAM_THRESHOLD),
         splt_t_get_float_option(state, SPLT_OPT_PARAM_OFFSET),
         splt_t_get_float_option(state, SPLT_OPT_PARAM_MIN_LENGTH),
         remove_str);
-    splt_t_put_message_to_client(state, message);
+    splt_t_put_info_message_to_client(state, message);
   }
  
   if (we_read_silence_from_logs)
@@ -632,8 +673,9 @@ int splt_s_set_silence_splitpoints(splt_state *state, int *error)
     {
       state->split.get_silence_level(0, INT_MAX, state->split.silence_level_client_data);
     }
-    snprintf(message, 1024, " Found silence log file '%s' ! Reading silence points from file to save time ;)", log_fname);
-    splt_t_put_message_to_client(state,message);
+    snprintf(message, 1024, _(" Found silence log file '%s' ! Reading"
+          " silence points from file to save time ;)"), log_fname);
+    splt_t_put_info_message_to_client(state, message);
     found = splt_u_parse_ssplit_file(state, log_file, error);
     if (log_file)
     {
@@ -656,8 +698,8 @@ int splt_s_set_silence_splitpoints(splt_state *state, int *error)
   {
     //put client infos
     char client_infos[512] = { '\0' };
-    snprintf(client_infos,512,"\n Total silence points found: %d.",found);
-    splt_t_put_message_to_client(state,client_infos);
+    snprintf(client_infos,512,_("\n Total silence points found: %d."),found);
+    splt_t_put_info_message_to_client(state,client_infos);
     if (found > 0)
     {
       int selected_tracks = found + 1;
@@ -666,17 +708,16 @@ int splt_s_set_silence_splitpoints(splt_state *state, int *error)
       {
         selected_tracks = param_number_of_tracks;
       }
-      snprintf(client_infos,512," (Selected %d tracks)\n", selected_tracks);
-      splt_t_put_message_to_client(state,client_infos);
+      snprintf(client_infos,512,_(" (Selected %d tracks)\n"), selected_tracks);
+      splt_t_put_info_message_to_client(state, client_infos);
     }
     else
     {
       snprintf(client_infos, 512, "\n");
-      splt_t_put_message_to_client(state,client_infos);
+      splt_t_put_info_message_to_client(state,client_infos);
     }
 
     //we set the number of tracks
-    int order = 0;
     if (!splt_t_split_is_canceled(state))
     {
       found++;
@@ -709,19 +750,19 @@ int splt_s_set_silence_splitpoints(splt_state *state, int *error)
             found = i;
             break;
           }
+
           if (splt_t_get_int_option(state, SPLT_OPT_PARAM_REMOVE_SILENCE))
           {
-            //we append 2 splitpoints
             append_error = splt_t_append_splitpoint(state, 0, NULL, SPLT_SKIPPOINT);
             if (append_error < 0) { *error = append_error; found = i; break;}
             append_error = splt_t_append_splitpoint(state, 0, NULL, SPLT_SPLITPOINT);
             if (append_error < 0) { *error = append_error; found = i; break;}
-            //we set the values
-            splt_t_set_splitpoint_value(state, 2*i-1,temp->begin_position * 100);
-            splt_t_set_splitpoint_value(state, 2*i,temp->end_position * 100);
+            splt_t_set_splitpoint_value(state, 2*i-1,splt_u_time_to_long(temp->begin_position));
+            splt_t_set_splitpoint_value(state, 2*i, splt_u_time_to_long(temp->end_position));
           }
           else
           {
+            //TODO
             long temp_silence_pos = splt_u_silence_position(temp, offset) * 100;
             append_error = splt_t_append_splitpoint(state, temp_silence_pos, NULL, SPLT_SPLITPOINT);
             if (append_error != SPLT_OK) { *error = append_error; found = i; break; }
@@ -732,18 +773,20 @@ int splt_s_set_silence_splitpoints(splt_state *state, int *error)
         //we order the splitpoints
         if (splt_t_get_int_option(state, SPLT_OPT_PARAM_REMOVE_SILENCE))
         {
-          order = (found-1)*2+1;
+          splitpoints_appended = (found-1)*2+1;
         }
         else 
         {
-          order = found;
+          splitpoints_appended = found;
         }
 
-        splt_u_print_debug("We order splitpoints...",0,NULL);
-        splt_u_order_splitpoints(state, order);
+        splt_u_print_debug(state,"We order splitpoints...",0,NULL);
+        splt_u_order_splitpoints(state, splitpoints_appended);
 
         //last splitpoint, end of file
-        append_error = splt_t_append_splitpoint(state, splt_t_get_total_time(state), NULL, SPLT_SPLITPOINT);
+        append_error =
+          splt_t_append_splitpoint(state, splt_t_get_total_time(state),
+              NULL, SPLT_SPLITPOINT);
         if (append_error != SPLT_OK) { *error = append_error; }
       }
     }
@@ -761,43 +804,46 @@ int splt_s_set_silence_splitpoints(splt_state *state, int *error)
         char *message = malloc(sizeof(char) * 1024);
         if (message)
         {
-          snprintf(message, 1023, " Writing silence log file '%s' ...\n",
+          snprintf(message, 1023, _(" Writing silence log file '%s' ...\n"),
               splt_t_get_silence_log_fname(state));
-          splt_t_put_message_to_client(state, message);
+          splt_t_put_info_message_to_client(state, message);
           if (message)
           {
             free(message);
             message = NULL;
           }
           char *fname = splt_t_get_silence_log_fname(state);
-          FILE *log_file = NULL;
-          if (!(log_file = splt_u_fopen(fname, "w")))
+          if (! splt_t_get_int_option(state, SPLT_OPT_PRETEND_TO_SPLIT))
           {
-            splt_t_set_strerror_msg(state);
-            splt_t_set_error_data(state, fname);
-            *error = SPLT_ERROR_CANNOT_OPEN_FILE;
-          }
-          else
-          {
-            //do the effective write
-            struct splt_ssplit *temp = state->silence_list;
-            fprintf(log_file, "%s\n", splt_t_get_filename_to_split(state));
-            fprintf(log_file, "%.2f\t%.2f\n", 
-                splt_t_get_float_option(state, SPLT_OPT_PARAM_THRESHOLD),
-                splt_t_get_float_option(state, SPLT_OPT_PARAM_MIN_LENGTH));
-            while (temp != NULL)
+            FILE *log_file = NULL;
+            if (!(log_file = splt_u_fopen(fname, "w")))
             {
-              fprintf(log_file, "%f\t%f\t%ld\n",
-                  temp->begin_position, temp->end_position, temp->len);
-              temp = temp->next;
+              splt_t_set_strerror_msg(state);
+              splt_t_set_error_data(state, fname);
+              *error = SPLT_ERROR_CANNOT_OPEN_FILE;
             }
-            fflush(log_file);
-            if (log_file)
+            else
             {
-              fclose(log_file);
-              log_file = NULL;
+              //do the effective write
+              struct splt_ssplit *temp = state->silence_list;
+              fprintf(log_file, "%s\n", splt_t_get_filename_to_split(state));
+              fprintf(log_file, "%.2f\t%.2f\n", 
+                  splt_t_get_float_option(state, SPLT_OPT_PARAM_THRESHOLD),
+                  splt_t_get_float_option(state, SPLT_OPT_PARAM_MIN_LENGTH));
+              while (temp != NULL)
+              {
+                fprintf(log_file, "%f\t%f\t%ld\n",
+                    temp->begin_position, temp->end_position, temp->len);
+                temp = temp->next;
+              }
+              fflush(log_file);
+              if (log_file)
+              {
+                fclose(log_file);
+                log_file = NULL;
+              }
+              temp = NULL;
             }
-            temp = NULL;
           }
         }
         else
@@ -809,9 +855,7 @@ int splt_s_set_silence_splitpoints(splt_state *state, int *error)
   }
   splt_t_ssplit_free(&state->silence_list);
 
-  //set number of splitpoints
-  //TODO:verify here ?
-  splt_t_set_splitnumber(state, found + 1);
+  splt_t_set_splitnumber(state, splitpoints_appended + 1);
 
   return found;
 }
@@ -820,10 +864,10 @@ int splt_s_set_silence_splitpoints(splt_state *state, int *error)
 //possible error in error
 void splt_s_silence_split(splt_state *state, int *error)
 {
-  splt_u_print_debug("Starting silence split ...",0,NULL);
+  splt_u_print_debug(state,"Starting silence split ...",0,NULL);
 
   //print some useful infos to the client
-  splt_t_put_message_to_client(state, " info: starting silence mode split\n");
+  splt_t_put_info_message_to_client(state, _(" info: starting silence mode split\n"));
 
   int found = 0;
   found = splt_s_set_silence_splitpoints(state, error);
@@ -835,7 +879,7 @@ void splt_s_silence_split(splt_state *state, int *error)
     if (found > 1)
     {
       //we put the number of tracks found
-      splt_u_print_debug("Writing silence tracks...",0,NULL);
+      splt_u_print_debug(state,"Writing silence tracks...",0,NULL);
 
       //set the default silence output
       int output_filenames = splt_t_get_int_option(state,SPLT_OPT_OUTPUT_FILENAMES);
@@ -879,9 +923,9 @@ void splt_s_wrap_split(splt_state *state, int *error)
   char *new_filename_path = splt_t_get_new_filename_path(state);
   char *filename = splt_t_get_filename_to_split(state);
 
-  splt_u_print_debug("We begin wrap split for the file ...",0,filename);
+  splt_u_print_debug(state,"We begin wrap split for the file ...",0,filename);
 
-  splt_t_put_message_to_client(state, " info: starting wrap mode split\n");
+  splt_t_put_info_message_to_client(state, _(" info: starting wrap mode split\n"));
 
   splt_p_dewrap(state, SPLT_FALSE, new_filename_path, error);
 }
